@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -28,6 +28,7 @@
 #include <QTimer>
 #include <QMimeDatabase>
 #include <QSize>
+#include <QtQmlIntegration>
 
 class QSize;
 class QFileSystemWatcher;
@@ -35,6 +36,7 @@ class QFileSystemWatcher;
 class PQCFileFolderModel : public QObject {
 
     Q_OBJECT
+    QML_SINGLETON
 
 public:
     static PQCFileFolderModel& get();
@@ -94,6 +96,10 @@ public:
     bool getReadArchiveOnly();
     void setReadArchiveOnly(bool c);
 
+    Q_PROPERTY(QStringList extraFoldersToLoad READ getExtraFoldersToLoad WRITE setExtraFoldersToLoad NOTIFY extraFoldersToLoadChanged)
+    QStringList getExtraFoldersToLoad();
+    void setExtraFoldersToLoad(QStringList val);
+
     /********************************************/
     /********************************************/
 
@@ -137,9 +143,15 @@ public:
     int getCurrentIndex();
     void setCurrentIndex(int val);
 
+    Q_PROPERTY(int currentIndexNoDelay READ getCurrentIndexNoDelay NOTIFY currentIndexNoDelayChanged)
+    int getCurrentIndexNoDelay();
+
     Q_PROPERTY(QString currentFile READ getCurrentFile NOTIFY currentFileChanged)
     QString getCurrentFile();
 
+    Q_PROPERTY(QString currentFileNoDelay READ getCurrentFileNoDelay NOTIFY currentFileNoDelayChanged)
+    QString getCurrentFileNoDelay();
+
     Q_PROPERTY(bool isPDF READ getIsPDF NOTIFY isPDFChanged)
     bool getIsPDF();
 
@@ -177,6 +189,10 @@ public:
 
     Q_INVOKABLE void resetModel();
 
+    /********************************************/
+
+    QTimer *timerNotifyCurrentIndexChanged;
+
 private:
     PQCFileFolderModel(QObject *parent = 0);
 
@@ -195,6 +211,7 @@ private:
     bool m_readDocumentOnly;
     bool m_readArchiveOnly;
     bool m_includeFilesInSubFolders;
+    QStringList m_extraFoldersToLoad;
 
     QStringList m_entriesMainView;
     QStringList m_entriesFileDialog;
@@ -208,7 +225,9 @@ private:
     bool m_filterCurrentlyActive;
 
     int m_currentIndex;
+    int m_currentIndexNoDelay;
     QString m_currentFile;
+    QString m_currentFileNoDelay;
 
     bool m_isPDF;
     bool m_isARC;
@@ -221,7 +240,7 @@ private:
     QTimer *loadDelayFileDialog;
 
     QStringList getAllFolders(QString folder, bool forceShowHidden = false);
-    QStringList getAllFiles(QString folder, bool ignoreFiltersExceptDefault = false);
+    QStringList getAllFiles(QString folder, bool ignoreFiltersExceptDefault = false, bool enforceOnlyIncludingThisFolder = false);
 
     QMimeDatabase db;
 
@@ -273,9 +292,12 @@ Q_SIGNALS:
     void readDocumentOnlyChanged();
     void readArchiveOnlyChanged();
     void includeFilesInSubFoldersChanged();
+    void extraFoldersToLoadChanged();
     void advancedSortDoneChanged();
     void currentIndexChanged();
+    void currentIndexNoDelayChanged();
     void currentFileChanged();
+    void currentFileNoDelayChanged();
     void isPDFChanged();
     void isARCChanged();
     void pdfNameChanged();
