@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -39,6 +39,9 @@ public:
 
     void calculateColors(QString name);
 
+    Q_PROPERTY(QString iconShade READ getIconShade NOTIFY iconShadeChanged)
+    QString getIconShade();
+
     /******************************************************/
 
     Q_PROPERTY(QString baseColor READ getBaseColor WRITE setBaseColor NOTIFY baseColorChanged)
@@ -54,9 +57,11 @@ public:
     /******************************************************/
 
     Q_PROPERTY(QString inverseColor READ getInverseColor NOTIFY inverseColorChanged)
+    Q_PROPERTY(QString inverseColorAccent READ getInverseColorAccent NOTIFY inverseColorAccentChanged)
     Q_PROPERTY(QString inverseColorHighlight READ getInverseColorHighlight NOTIFY inverseColorHighlightChanged)
     Q_PROPERTY(QString inverseColorActive READ getInverseColorActive NOTIFY inverseColorActiveChanged)
     QString getInverseColor();
+    QString getInverseColorAccent();
     QString getInverseColorHighlight();
     QString getInverseColorActive();
 
@@ -75,6 +80,11 @@ public:
 
     /******************************************************/
 
+    Q_PROPERTY(QString transInverseColor READ getTransInverseColor NOTIFY transInverseColorChanged)
+    QString getTransInverseColor();
+
+    /******************************************************/
+
     Q_PROPERTY(QString textColor READ getTextColor NOTIFY textColorChanged)
     Q_PROPERTY(QString textColorDisabled READ getTextColorDisabled NOTIFY textColorDisabledChanged)
     QString getTextColor();
@@ -117,16 +127,22 @@ public:
     /******************************************************/
 
     Q_INVOKABLE QStringList getColorNames();
+    Q_INVOKABLE QStringList getColorHexes();
 
 private:
     PQCLook();
 
+    int lightness_threshold;
+
+    QString m_iconShade;
+
     QString m_baseColor;
     QString m_baseColorAccent;
     QString m_baseColorHighlight;
     QString m_baseColorActive;
 
     QString m_inverseColor;
+    QString m_inverseColorAccent;
     QString m_inverseColorHighlight;
     QString m_inverseColorActive;
 
@@ -136,6 +152,8 @@ private:
     QString m_transColorHighlight;
     QString m_transColorActive;
 
+    QString m_transInverseColor;
+
     QString m_textColor;
     QString m_textColorDisabled;
 
@@ -152,8 +170,8 @@ private:
     int m_fontWeightBold;
     int m_fontWeightNormal;
 
-    QHash<QString,QString> colorNameToHex;
     QStringList colorNames;
+    QStringList colorHexes;
 
 Q_SIGNALS:
     void baseColorChanged();
@@ -162,6 +180,7 @@ Q_SIGNALS:
     void baseColorActiveChanged();
 
     void inverseColorChanged();
+    void inverseColorAccentChanged();
     void inverseColorHighlightChanged();
     void inverseColorActiveChanged();
 
@@ -171,6 +190,8 @@ Q_SIGNALS:
     void transColorHighlightChanged();
     void transColorActiveChanged();
 
+    void transInverseColorChanged();
+
     void textColorChanged();
     void textColorDisabledChanged();
 
@@ -187,6 +208,8 @@ Q_SIGNALS:
     void fontWeightBoldChanged();
     void fontWeightNormalChanged();
 
+    void iconShadeChanged();
+
 };
 
 #endif
