@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -24,10 +24,12 @@
 #define PQCSCRIPTSFILEMANAGEMENT_H
 
 #include <QObject>
+#include <QtQmlIntegration>
 
 class PQCScriptsFileManagement : public QObject {
 
     Q_OBJECT
+    QML_SINGLETON
 
 public:
     static PQCScriptsFileManagement& get() {
