@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -26,12 +26,14 @@
 #include <QObject>
 #include <QNetworkReply>
 #include <QSqlDatabase>
+#include <QtQmlIntegration>
 
 class QNetworkAccessManager;
 
 class PQCScriptsShareImgur : public QObject {
 
     Q_OBJECT
+    QML_SINGLETON
 
 public:
 
