@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -71,33 +71,34 @@ QString PQCLoadImageLibVips::load(QString filename, QSize maxSize, QSize &origSi
 
     // we use the C API as the equivalent C++ API calls led to crash on subsequent call
 
-    // The vips image object
-    VipsImage *in;
-
     // attempt to the load the image
-    if(!(in = vips_image_new_from_file(filename.toStdString().c_str(), NULL))) {
-        g_object_unref(in);
+    VipsImage *vimg = vips_image_new_from_file(filename.toStdString().c_str(), "memory", true, NULL);
+    if(vimg == NULL) {
         errormsg = "vips_image_new_from_file: failed to load image from file";
         qDebug() << errormsg;
         return errormsg;
     }
 
     // store original size
-    origSize = QSize(vips_image_get_width(in), vips_image_get_height(in));
+    origSize = QSize(vimg->Xsize, vimg->Ysize);
 
-    // convert VipsImage to QImage
-    img = QImage((uchar*)vips_image_get_data(in), vips_image_get_width(in), vips_image_get_height(in), VIPS_IMAGE_SIZEOF_LINE(in), QImage::Format_RGB888);
+    void *buf = nullptr;
+    size_t len = 0;
+    vips_image_write_to_buffer(vimg, ".png", &buf, &len, NULL);
+
+    // Convert VipsImage to raw data
+    img.loadFromData(reinterpret_cast<const uchar *>(buf), len);
     if(img.isNull()) {
         errormsg = "converting VipsImage to QImage failed";
         qDebug() << errormsg;
         return errormsg;
     }
 
-    if(!PQCScriptsImages::get().applyColorProfile(filename, img))
-        Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "The selected color profile could not be applied."));
+    PQCScriptsImages::get().applyColorProfile(filename, img);
     PQCImageCache::get().saveImageToCache(filename, PQCScriptsImages::get().getColorProfileFor(filename), &img);
 
-    g_object_unref(in);
+    g_object_unref(vimg);
+    g_free(buf);
 
     // Scale image if necessary
     if(maxSize.width() != -1) {
