@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -111,8 +111,7 @@ QString PQCLoadImagePoppler::load(QString filename, QSize maxSize, QSize &origSi
     img = p->renderToImage(useQuality, useQuality);
 
     if(!img.isNull()) {
-        if(!PQCScriptsImages::get().applyColorProfile(filename, img))
-            Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "The selected color profile could not be applied."));
+        PQCScriptsImages::get().applyColorProfile(filename, img);
         PQCImageCache::get().saveImageToCache(filename, PQCScriptsImages::get().getColorProfileFor(filename), &img);
     }
 
