@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -38,8 +38,6 @@ PQCLoadImageQt::PQCLoadImageQt() {
 
 QSize PQCLoadImageQt::loadSize(QString filename) {
 
-    QString errormsg = "";
-
     // Suffix, for easier access later-on
     QString suffix = QFileInfo(filename).suffix().toLower();
 
@@ -89,7 +87,6 @@ QSize PQCLoadImageQt::loadSize(QString filename) {
         if(origSize.width() == -1 || origSize.height() == -1) {
             QImage img;
             reader.read(&img);
-            imgAlreadyLoaded = true;
             return img.size();
         }
 
@@ -179,8 +176,30 @@ QString PQCLoadImageQt::load(QString filename, QSize maxSize, QSize &origSize, Q
             origSize = img.size();
             if(!img.isNull()) {
                 colorProfileAlreadyApplied = true;
-                if(!PQCScriptsImages::get().applyColorProfile(filename, img))
-                    Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "The selected color profile could not be applied."));
+                PQCScriptsImages::get().applyColorProfile(filename, img);
+                PQCImageCache::get().saveImageToCache(filename, PQCScriptsImages::get().getColorProfileFor(filename), &img);
+            }
+        }
+
+        // If QImageReader cannot read the image does not mean all hope is lost
+        if(!reader.canRead()) {
+
+            errormsg = "unable to read image with reader, trying direct QImage";
+            qDebug() << errormsg;
+
+            // It is possible that QImage can load an image directly even if QImageReader cannot
+            img.load(filename);
+            imgAlreadyLoaded = true;
+            origSize = img.size();
+
+            if(img.isNull()) {
+                errormsg = "image reader and QImage unable to read image";
+                qWarning() << errormsg;
+                return errormsg;
+            } else {
+                errormsg = "";
+                colorProfileAlreadyApplied = true;
+                PQCScriptsImages::get().applyColorProfile(filename, img);
                 PQCImageCache::get().saveImageToCache(filename, PQCScriptsImages::get().getColorProfileFor(filename), &img);
             }
         }
@@ -200,34 +219,24 @@ QString PQCLoadImageQt::load(QString filename, QSize maxSize, QSize &origSize, Q
 
         }
 
-        // Eventually load the image
-        if(!reader.canRead()) {
-            errormsg = "image reader unable to read image";
-            qWarning() << errormsg;
-            return errormsg;
-        }
-
-        if(!imgAlreadyLoaded) {
+        if(!imgAlreadyLoaded && reader.canRead()) {
             reader.read(&img);
             if(!img.isNull() && img.size() == origSize) {
                 colorProfileAlreadyApplied = true;
-                if(!PQCScriptsImages::get().applyColorProfile(filename, img))
-                    Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "The selected color profile could not be applied."));
+                PQCScriptsImages::get().applyColorProfile(filename, img);
                 PQCImageCache::get().saveImageToCache(filename, PQCScriptsImages::get().getColorProfileFor(filename), &img);
             }
         }
 
-        // If an error occured
+        // If an error occurred
         if(img.isNull()) {
             errormsg = reader.errorString();
             qWarning() << errormsg;
             return errormsg;
         }
 
-        if(!colorProfileAlreadyApplied) {
-            if(!PQCScriptsImages::get().applyColorProfile(filename, img))
-                Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "The selected color profile could not be applied."));
-        }
+        if(!colorProfileAlreadyApplied)
+            PQCScriptsImages::get().applyColorProfile(filename, img);
 
         return "";
 
