@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -52,7 +52,7 @@ QSize PQCLoadImageQtPDF::loadSize(QString filename) {
 
     QPdfDocument::Error err = doc.error();
     if(err != QPdfDocument::Error::None) {
-        qWarning() << "Error occured loading PDF";
+        qWarning() << "Error occurred loading PDF";
         return QSize();
     }
 
@@ -88,7 +88,7 @@ QString PQCLoadImageQtPDF::load(QString filename, QSize maxSize, QSize &origSize
 
     QPdfDocument::Error err = doc.error();
     if(err != QPdfDocument::Error::None) {
-        errormsg = "Error occured loading PDF";
+        errormsg = "Error occurred loading PDF";
         qWarning() << errormsg;
         return errormsg;
     }
@@ -114,8 +114,7 @@ QString PQCLoadImageQtPDF::load(QString filename, QSize maxSize, QSize &origSize
     paint.end();
 
     if(!img.isNull()) {
-        if(!PQCScriptsImages::get().applyColorProfile(filename, img))
-            Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "The selected color profile could not be applied."));
+        PQCScriptsImages::get().applyColorProfile(filename, img);
         PQCImageCache::get().saveImageToCache(filename, PQCScriptsImages::get().getColorProfileFor(filename), &img);
     }
 
