@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -34,6 +34,11 @@
     #endif
 #endif
 
+// This needs to come early (in particular before the FreImage header)
+#ifdef Q_OS_WIN
+    #include <windows.h>
+#endif
+
 #include <pqc_configfiles.h>
 #include <pqc_singleinstance.h>
 #include <pqc_startup.h>
@@ -77,11 +82,7 @@
 #include <scripts/pqc_scriptschromecast.h>
 #include <scripts/pqc_scriptsundo.h>
 
-#ifdef PQMGRAPHICSMAGICK
-#include <GraphicsMagick/Magick++.h>
-#endif
-
-#ifdef PQMIMAGEMAGICK
+#if defined(PQMIMAGEMAGICK) || defined(PQMGRAPHICSMAGICK)
 #include <Magick++.h>
 #endif
 
@@ -93,9 +94,7 @@
 #include <vips/vips8>
 #endif
 
-#ifdef PQMVIDEOMPV
 #include <pqc_mpvobject.h>
-#endif
 
 #ifdef PQMEXIV2
 #include <exiv2/exiv2.hpp>
@@ -133,6 +132,25 @@ int main(int argc, char *argv[]) {
     QQuickWindow::setGraphicsApi(QSGRendererInterface::OpenGL);
 #endif
 
+#ifdef PQMPORTABLETWEAKS
+    if(argc > 1) {
+        qputenv("PHOTOQT_EXE_BASEDIR", argv[1]);
+        // create directory and set hidden attribute
+#ifdef Q_OS_WIN
+        QString folder = QString("%1/photoqt-data").arg(argv[1]);
+        QDir dir;
+        dir.mkdir(folder);
+        SetFileAttributesA(dir.toNativeSeparators(folder).toLocal8Bit(), FILE_ATTRIBUTE_HIDDEN);
+#else
+        QString folder = QString("%1/.photoqt-data").arg(argv[1]);
+        QDir dir;
+        dir.mkdir(folder);
+#endif
+    } else {
+        qputenv("PHOTOQT_EXE_BASEDIR", f.absolutePath().toLocal8Bit());
+    }
+#endif
+
     // avoids warning for customizing native styles (observed in particular on Windows)
     qputenv("QT_QUICK_CONTROLS_IGNORE_CUSTOMIZATION_WARNINGS", "1");
 
@@ -144,13 +162,13 @@ int main(int argc, char *argv[]) {
     QApplication::setQuitOnLastWindowClosed(true);
 
     // Set the desktop filename. On Wayland this is necessary to set the icon in the window title and panel
-    QGuiApplication::setDesktopFileName("org.photoqt.PhotoQt.desktop");
+    QGuiApplication::setDesktopFileName("org.photoqt.PhotoQt");
 
     // custom message handler for qDebug/qLog/qInfo/etc.
     qInstallMessageHandler(pqcMessageHandler);
 
     // needs to be set before Q*Application is created
-    QFile opengl(PQCConfigFiles::CONFIG_DIR()+"/OpenGL");
+    QFile opengl(PQCConfigFiles::get().CONFIG_DIR()+"/OpenGL");
     if(opengl.exists()) {
         if(opengl.open(QIODevice::ReadOnly)) {
             QTextStream in (&opengl);
@@ -169,6 +187,15 @@ int main(int argc, char *argv[]) {
         }
     }
 
+#ifdef PQMPORTABLETWEAKS
+    if(argc > 1) {
+        for(int i = 2; i < argc; ++i) {
+            argv[i-1] = argv[i];
+        }
+        argc -= 1;
+    }
+#endif
+
     // only a single instance
     PQCSingleInstance app(argc, argv);
 
@@ -179,8 +206,13 @@ int main(int argc, char *argv[]) {
 #endif
 
 #ifdef PQMEXIV2
-    #ifdef PQMEXIV2_ENABLE_BMFF
-        Exiv2::enableBMFF(true);
+    #if EXIV2_TEST_VERSION(0, 28, 0)
+        // In this case Exiv2::enableBMFF() defaults to true
+        // and the call to it is deprecated
+    #else
+        #ifdef PQMEXIV2_ENABLE_BMFF
+            Exiv2::enableBMFF(true);
+        #endif
     #endif
 #endif
 
@@ -269,7 +301,7 @@ int main(int argc, char *argv[]) {
 
     // create the qml engine
     QQmlApplicationEngine engine;
-    const QUrl url(u"qrc:/src/qml/PQMainWindow.qml"_qs);
+    const QUrl url("qrc:/src/qml/PQMainWindow.qml");
     QObject::connect(&engine, &QQmlApplicationEngine::objectCreated,
         &app, [url](QObject *obj, const QUrl &objUrl) {
             if(!obj && url == objUrl)
@@ -319,9 +351,8 @@ int main(int argc, char *argv[]) {
     qmlRegisterType<PQCPhotoSphere>("PQCPhotoSphere", 1, 0, "PQCPhotoSphere");
 #endif
 
-#ifdef PQMVIDEOMPV
+    // if MPV support is disabled, then this is an empty object
     qmlRegisterType<PQCMPVObject>("PQCMPVObject", 1, 0, "PQCMPVObject");
-#endif
 
     engine.load(url);
 
