@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -35,6 +35,7 @@
 #include <pqc_notify.h>
 #include <pqc_settings.h>
 #include <pqc_configfiles.h>
+#include <pqc_filefoldermodel.h>
 
 PQCSingleInstance::PQCSingleInstance(int &argc, char *argv[]) : QApplication(argc, argv) {
 
@@ -49,10 +50,12 @@ PQCSingleInstance::PQCSingleInstance(int &argc, char *argv[]) : QApplication(arg
     server = nullptr;
 
     if(result & PQCCommandLineFile) {
-        QString fullfilename = parser.filename;
-        if(!QFileInfo(fullfilename).isAbsolute())
-            fullfilename = QDir::currentPath() + "/" + parser.filename;
-        message += ":://::_F_I_L_E_" + QFileInfo(fullfilename).canonicalFilePath().toUtf8();
+        for(const auto &f : parser.filenames) {
+            QString ff = f;
+            if(!QFileInfo(ff).isAbsolute())
+                ff = QDir::currentPath() + "/" + ff;
+            message += ":://::_F_I_L_E_" + QFileInfo(ff).canonicalFilePath().toUtf8();
+        }
     }
 
     if(result & PQCCommandLineOpen)
@@ -139,14 +142,14 @@ PQCSingleInstance::PQCSingleInstance(int &argc, char *argv[]) : QApplication(arg
     this->installEventFilter(this);
 
     // we need to figure out if multiple instances are allowed here WITHOUT using the PQCSettings class
-    if(QFile::exists(PQCConfigFiles::SETTINGS_DB())) {
+    if(QFile::exists(PQCConfigFiles::get().SETTINGS_DB())) {
         QSqlDatabase dbtmp;
         if(QSqlDatabase::isDriverAvailable("QSQLITE3"))
             dbtmp = QSqlDatabase::addDatabase("QSQLITE3", "settingsmultiple");
         else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
             dbtmp = QSqlDatabase::addDatabase("QSQLITE", "settingsmultiple");
         dbtmp.setConnectOptions("QSQLITE_OPEN_READONLY");
-        dbtmp.setDatabaseName(PQCConfigFiles::SETTINGS_DB());
+        dbtmp.setDatabaseName(PQCConfigFiles::get().SETTINGS_DB());
         if(!dbtmp.open()) {
             qWarning() << "Unable to check how to handle multiple instances:" << dbtmp.lastError().text();
             qWarning() << "Assuming only a single instance is to be used";
@@ -180,7 +183,7 @@ PQCSingleInstance::PQCSingleInstance(int &argc, char *argv[]) : QApplication(arg
     socket = new QLocalSocket();
     socket->connectToServer(server_str);
 
-    // If this is successfull, then an instance is already running
+    // If this is successful, then an instance is already running
     if(socket->waitForConnected(100)) {
 
         if(message == "")
@@ -226,13 +229,24 @@ void PQCSingleInstance::handleMessage(QString msg) {
 
     QStringList parts = msg.split(":://::");
 
+    QStringList allfiles;
+    QStringList allfolders;
+
     for(const QString &m : std::as_const(parts)) {
 
-        if(m.startsWith("_F_I_L_E_"))
+        if(m.startsWith("_F_I_L_E_")) {
 
-            PQCNotify::get().setFilePath(m.last(m.length()-9));
+            // sort by files and folders
+            // that way we can make sure to always load the first specified file as initial image
+            QFileInfo info(m.last(m.length()-9));
+            if(!info.exists())
+                continue;
+            if(info.isFile())
+                allfiles.append(m.last(m.length()-9));
+            else if(info.isDir())
+                allfolders.append(m.last(m.length()-9));
 
-        else if(m == "_O_P_E_N_")
+        } else if(m == "_O_P_E_N_")
 
             Q_EMIT PQCNotify::get().cmdOpen();
 
@@ -282,11 +296,22 @@ void PQCSingleInstance::handleMessage(QString msg) {
 
     }
 
+    // if we have files and/or folders that were passed on
+    if(allfiles.length() > 0 || allfolders.length() > 0) {
+        allfiles.append(allfolders);
+        if(allfiles.length() > 1)
+            PQCFileFolderModel::get().setExtraFoldersToLoad(allfiles.mid(1));
+        else
+            PQCFileFolderModel::get().setExtraFoldersToLoad({});
+        PQCNotify::get().setFilePath(allfiles[0]);
+    }
+
 }
 
 bool PQCSingleInstance::eventFilter(QObject *obj, QEvent *e) {
 
     if(e->type() == QEvent::KeyPress && !PQCNotify::get().getModalFileDialogOpen()) {
+
         QKeyEvent *ev = reinterpret_cast<QKeyEvent*>(e);
 
         // These events are ignored if a spinbox is focussed:
@@ -311,6 +336,17 @@ bool PQCSingleInstance::eventFilter(QObject *obj, QEvent *e) {
 
         Q_EMIT PQCNotify::get().keyPress(ev->key(), ev->modifiers());
         return true;
+
+    // this is to be used very sparingly and carefully to not react to events twice!
+    } else if(e->type() == QEvent::KeyRelease) {
+
+        QKeyEvent *ev = reinterpret_cast<QKeyEvent*>(e);
+        Q_EMIT PQCNotify::get().keyRelease(ev->key(), ev->modifiers());
+
+    } else if(e->type() == QEvent::Leave) {
+        Q_EMIT PQCNotify::get().mouseWindowExit();
+    } else if(e->type() == QEvent::Enter) {
+        Q_EMIT PQCNotify::get().mouseWindowEnter();
     }
 
     return QApplication::eventFilter(obj, e);
