@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -44,9 +44,9 @@ PQCImageFormats::PQCImageFormats() {
         db = QSqlDatabase::addDatabase("QSQLITE3", "imageformats");
     else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
         db = QSqlDatabase::addDatabase("QSQLITE", "imageformats");
-    db.setDatabaseName(PQCConfigFiles::IMAGEFORMATS_DB());
+    db.setDatabaseName(PQCConfigFiles::get().IMAGEFORMATS_DB());
 
-    QFileInfo infodb(PQCConfigFiles::IMAGEFORMATS_DB());
+    QFileInfo infodb(PQCConfigFiles::get().IMAGEFORMATS_DB());
 
     if(!infodb.exists() || !db.open()) {
 
@@ -632,7 +632,7 @@ bool PQCImageFormats::enterNewFormat(QString endings, QString mimetypes, QString
     int howmany = query.record().value("NumFormats").toInt();
     if(howmany != 0) {
         if(!silentIfExists)
-            qDebug() << "Found" << howmany << "format with the new descrption, not entering anything new.";
+            qDebug() << "Found" << howmany << "format with the new description, not entering anything new.";
         return false;
     }
 
@@ -759,12 +759,12 @@ void PQCImageFormats::restoreDefaults() {
         return;
     }
 
-    QFile::remove(PQCConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
-    QFile::copy(":/imageformats.db", PQCConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
-    QFile::setPermissions(PQCConfigFiles::CACHE_DIR()+"/photoqt_tmp.db",
+    QFile::remove(PQCConfigFiles::get().CACHE_DIR()+"/photoqt_tmp.db");
+    QFile::copy(":/imageformats.db", PQCConfigFiles::get().CACHE_DIR()+"/photoqt_tmp.db");
+    QFile::setPermissions(PQCConfigFiles::get().CACHE_DIR()+"/photoqt_tmp.db",
                           QFileDevice::WriteOwner|QFileDevice::ReadOwner |
                               QFileDevice::ReadGroup);
-    dbdefault.setDatabaseName(PQCConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
+    dbdefault.setDatabaseName(PQCConfigFiles::get().CACHE_DIR()+"/photoqt_tmp.db");
     if(!dbdefault.open()) {
         qWarning() << "SQL error:" << dbdefault.lastError().text();
         dbdefault.close();
