@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -42,15 +42,15 @@ PQCLocation::PQCLocation(QObject *parent) : QObject(parent) {
         db = QSqlDatabase::addDatabase("QSQLITE3", "location");
     else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
         db = QSqlDatabase::addDatabase("QSQLITE", "location");
-    db.setDatabaseName(PQCConfigFiles::LOCATION_DB());
+    db.setDatabaseName(PQCConfigFiles::get().LOCATION_DB());
 
     dbOpened = false;
 
-    QFileInfo infodb(PQCConfigFiles::LOCATION_DB());
+    QFileInfo infodb(PQCConfigFiles::get().LOCATION_DB());
 
     if(!infodb.exists()) {
         qWarning() << "ERROR: database file does not exist, attempting to create";
-        if(!QFile::copy(":/location.db", PQCConfigFiles::LOCATION_DB())) {
+        if(!QFile::copy(":/location.db", PQCConfigFiles::get().LOCATION_DB())) {
             qWarning() << "Unable to create new location database, location caching will be unavailable";
             return;
         }
@@ -316,7 +316,9 @@ void PQCLocation::processSummary(QString folder) {
     query.clear();
 
     QCollator collator;
+#ifndef PQMWITHOUTICU
     collator.setNumericMode(true);
+#endif
     std::sort(images.begin(), images.end(), [&collator](const QVariant &file1, const QVariant &file2) { return collator.compare(file1.toList()[0].toString(), file2.toList()[0].toString()) < 0; });
 
     m_imageList = items;
