@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -34,7 +34,7 @@ PQCSettings::PQCSettings() {
         db = QSqlDatabase::addDatabase("QSQLITE3", "settings");
     else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
         db = QSqlDatabase::addDatabase("QSQLITE", "settings");
-    db.setDatabaseName(PQCConfigFiles::SETTINGS_DB());
+    db.setDatabaseName(PQCConfigFiles::get().SETTINGS_DB());
 
     dbtables = QStringList() << "general"
                              << "interface"
@@ -51,7 +51,7 @@ PQCSettings::PQCSettings() {
 
     readonly = false;
 
-    QFileInfo infodb(PQCConfigFiles::SETTINGS_DB());
+    QFileInfo infodb(PQCConfigFiles::get().SETTINGS_DB());
 
     if(!infodb.exists() || !db.open()) {
 
@@ -183,8 +183,10 @@ void PQCSettings::readDB() {
                 }
             } else if(datatype == "string")
                 this->insert(name, value);
-            else
+            else if(datatype != "")
                 qCritical() << QString("ERROR: datatype not handled for setting '%1':").arg(name) << datatype;
+            else
+                qDebug() << QString("empty datatype found for setting '%1' -> ignoring").arg(name);
 
 #ifndef NDEBUG
             valid.push_back(name);
@@ -208,10 +210,10 @@ bool PQCSettings::backupDatabase() {
     }
 
     // backup file
-    if(QFile::exists(QString("%1.bak").arg(PQCConfigFiles::SETTINGS_DB())))
-        QFile::remove(QString("%1.bak").arg(PQCConfigFiles::SETTINGS_DB()));
-    QFile file(PQCConfigFiles::SETTINGS_DB());
-    return file.copy(QString("%1.bak").arg(PQCConfigFiles::SETTINGS_DB()));
+    if(QFile::exists(QString("%1.bak").arg(PQCConfigFiles::get().SETTINGS_DB())))
+        QFile::remove(QString("%1.bak").arg(PQCConfigFiles::get().SETTINGS_DB()));
+    QFile file(PQCConfigFiles::get().SETTINGS_DB());
+    return file.copy(QString("%1.bak").arg(PQCConfigFiles::get().SETTINGS_DB()));
 
 }
 
@@ -322,6 +324,81 @@ void PQCSettings::setDefault(bool ignoreLanguage) {
 
 }
 
+void PQCSettings::setDefaultFor(QString key) {
+
+    qDebug() << "args: key =" << key;
+    qDebug() << "readonly =" << readonly;
+
+    if(readonly) return;
+
+    QString tablename = "";
+    QString settingname = "";
+
+    for(auto &t : std::as_const(dbtables)) {
+
+        if(key.startsWith(t)) {
+            tablename = t;
+            break;
+        }
+
+    }
+
+    // invalid table name
+    if(tablename == "") {
+        qWarning() << "tablename not found";
+        return;
+    }
+
+    settingname = key.last(key.size()-tablename.size());
+
+    QSqlQuery query(db);
+    query.prepare(QString("SELECT `defaultvalue`,`datatype` FROM '%1' WHERE name='%2'").arg(tablename,settingname));
+    if(!query.exec())
+        qWarning() << "SQL Error:" << query.lastError().text();
+
+    if(!query.next()) {
+        qWarning() << "unable to get default value";
+        return;
+    }
+
+    QString value = query.value(0).toString();
+    QString datatype = query.value(1).toString();
+
+
+    if(datatype == "int")
+        this->update(key, value.toInt());
+    else if(datatype == "double")
+        this->update(key, value.toDouble());
+    else if(datatype == "bool")
+        this->update(key, static_cast<bool>(value.toInt()));
+    else if(datatype == "list") {
+        if(value.contains(":://::"))
+            this->update(key, value.split(":://::"));
+        else if(value != "")
+            this->update(key, QStringList() << value);
+        else
+            this->update(key, QStringList());
+    } else if(datatype == "point") {
+        const QStringList parts = value.split(",");
+        if(parts.length() == 2)
+            this->update(key, QPoint(parts[0].toUInt(), parts[1].toInt()));
+        else {
+            qWarning() << QString("ERROR: invalid format of QPoint for setting '%1': '%2'").arg(key, value);
+            this->update(key, QPoint(0,0));
+        }
+    } else if(datatype == "size") {
+        const QStringList parts = value.split(",");
+        if(parts.length() == 2)
+            this->update(key, QSize(parts[0].toUInt(), parts[1].toInt()));
+        else {
+            qWarning() << QString("ERROR: invalid format of QSize for setting '%1': '%2'").arg(key, value);
+            this->update(key, QSize(0,0));
+        }
+    } else if(datatype == "string")
+        this->update(key, value);
+
+}
+
 void PQCSettings::update(QString key, QVariant value) {
     (*this)[key] = value;
     saveChangedValue(key, value);
@@ -413,7 +490,7 @@ int PQCSettings::migrate(QString oldversion) {
     /*************************************************************************/
 
     QStringList versions;
-    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4" << "4.5" << "4.6";
+    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4" << "4.5" << "4.6" << "4.7" << "4.8" << "4.8.1";
     // when removing the 'dev' value, check below for any if statement involving 'dev'!
 
     // this is a safety check to make sure we don't forget the above check
@@ -545,6 +622,69 @@ int PQCSettings::migrate(QString oldversion) {
 
             }
 
+        } else if(curVer == "4.7") {
+
+            QSqlQuery queryGet(db);
+            if(!queryGet.exec("SELECT `value` FROM `interface` WHERE `name`='AccentColor'")) {
+
+                qWarning() << "Unable to retrieve AccentColor setting:" << queryGet.lastError().text().trimmed();
+
+            } else {
+
+                queryGet.next();
+
+                QString val = queryGet.value(0).toString();
+                queryGet.clear();
+
+                QMap<QString,QString> mapping;
+                mapping.insert("gray",   "#222222");
+                mapping.insert("red",    "#110505");
+                mapping.insert("green" , "#051105");
+                mapping.insert("blue",   "#050b11");
+                mapping.insert("purple", "#0b0211");
+                mapping.insert("orange", "#110b02");
+                mapping.insert("pink",   "#110511");
+
+                if(mapping.contains(val)) {
+                    QSqlQuery queryUpd(db);
+                    if(!queryUpd.exec(QString("UPDATE `interface` SET `value`='%1' WHERE `name`='AccentColor'").arg(mapping[val])))
+                        qWarning() << "Unable to update AccentColor:" << queryUpd.lastError().text().trimmed();
+                    queryUpd.clear();
+                }
+
+            }
+
+            QSqlQuery queryChk(db);
+            if(!queryChk.exec("SELECT `value` FROM `imageview` WHERE `name`='Cache'")) {
+
+                qWarning() << "Unable to retrieve Cache setting:" << queryChk.lastError().text().trimmed();
+
+            } else {
+
+                queryChk.next();
+
+                int val = queryChk.value(0).toInt();
+                queryChk.clear();
+
+                if(val < 256) {
+
+                    QSqlQuery queryUpd(db);
+                    if(!queryUpd.exec(QString("UPDATE `imageview` SET `value`='256' WHERE `name`='Cache'")))
+                        qWarning() << "Unable to update Cache:" << queryUpd.lastError().text().trimmed();
+                    queryUpd.clear();
+
+                }
+
+            }
+        } else if(curVer == "4.8") {
+
+            QSqlQuery query(db);
+
+            query.prepare("UPDATE `imageview` SET `value`=0 WHERE `name`='ZoomToCenter'");
+            if(!query.exec())
+                qWarning() << "Unable to enable imageviewZoomToCenter by default:" << query.lastError().text().trimmed();
+            query.clear();
+
         }
 
         ////////////////////////////////////
