@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -96,6 +96,41 @@ PQCFileFolderModel::PQCFileFolderModel(QObject *parent) : QObject(parent) {
     loadDelayFileDialog->setSingleShot(true);
     connect(loadDelayFileDialog, &QTimer::timeout, this, &PQCFileFolderModel::loadDataFileDialog);
 
+    timerNotifyCurrentIndexChanged = new QTimer;
+    timerNotifyCurrentIndexChanged->setInterval(100);
+    timerNotifyCurrentIndexChanged->setSingleShot(true);
+    connect(timerNotifyCurrentIndexChanged, &QTimer::timeout, this, [=]() {
+
+        Q_EMIT currentIndexChanged();
+        Q_EMIT currentFileChanged();
+
+        bool ispdf = m_currentFile.indexOf("::PDF::")>-1;
+        if(m_isPDF != ispdf) {
+            m_isPDF = ispdf;
+            m_isARC = false;
+            if(ispdf) {
+                m_pdfName = m_currentFile.split("::PDF::")[1];
+                m_pdfNum = m_currentFile.split("::PDF::")[0].toInt();
+            }
+            Q_EMIT isPDFChanged();
+            Q_EMIT pdfNameChanged();
+            Q_EMIT pdfNumChanged();
+        }
+
+        bool isarc = m_currentFile.indexOf("::ARC::")>-1;
+        if(m_isARC != isarc) {
+            m_isPDF = false;
+            m_isARC = isarc;
+            if(m_isARC) {
+                m_arcName = m_currentFile.split("::ARC::")[1];
+                m_arcFile = m_currentFile.split("::ARC::")[0];
+            }
+            Q_EMIT isARCChanged();
+            Q_EMIT arcNameChanged();
+            Q_EMIT arcFileChanged();
+        }
+    });
+
     // we add a tiny delay to this signal to make sure that when the directory has changed all files are fully written
     // not having this delay can cause faulty thumbnails to be loaded
     connect(watcherMainView, &QFileSystemWatcher::directoryChanged, this, [=]() { m_fileInFolderMainView = m_currentFile; loadDelayMainView->start(); });
@@ -144,11 +179,15 @@ void PQCFileFolderModel::setFileInFolderMainView(QString val) {
     QFileInfo newfile(val);
     if(oldfile.dir() == newfile.dir() && m_fileInFolderMainView != "") {
         m_currentFile = val;
+        m_currentFileNoDelay = m_currentFile;
         m_currentIndex = m_entriesMainView.indexOf(val);
+        m_currentIndexNoDelay = m_currentIndex;
         m_fileInFolderMainView = val;
         Q_EMIT fileInFolderMainViewChanged();
         Q_EMIT currentFileChanged();
         Q_EMIT currentIndexChanged();
+        Q_EMIT currentFileNoDelayChanged();
+        Q_EMIT currentIndexNoDelayChanged();
     } else {
         m_fileInFolderMainView = val;
         loadDelayMainView->start();
@@ -256,6 +295,15 @@ void PQCFileFolderModel::setReadArchiveOnly(bool c) {
     loadDelayMainView->start();
 }
 
+QStringList PQCFileFolderModel::getExtraFoldersToLoad() {
+    return m_extraFoldersToLoad;
+}
+void PQCFileFolderModel::setExtraFoldersToLoad(QStringList val) {
+    m_extraFoldersToLoad = val;
+    Q_EMIT extraFoldersToLoadChanged();
+    loadDelayMainView->start();
+}
+
 /********************************************/
 /********************************************/
 
@@ -691,10 +739,12 @@ void PQCFileFolderModel::advancedSortMainView() {
         m_countMainView = tmp;
 
         m_currentIndex = cacheAdvancedSortFolder.indexOf(m_currentFile);
+        m_currentIndexNoDelay = m_currentIndex;
 
         m_entriesMainView = cacheAdvancedSortFolder;
         Q_EMIT countMainViewChanged();
         Q_EMIT currentIndexChanged();
+        Q_EMIT currentIndexNoDelayChanged();
         Q_EMIT newDataLoadedMainView();
         Q_EMIT entriesMainViewChanged();
         Q_EMIT advancedSortingComplete();
@@ -741,8 +791,6 @@ void PQCFileFolderModel::removeEntryMainView(int index) {
         cacheAdvancedSortFolder.removeOne(oldentry);
     }
 
-    loadDelayFileDialog->start();
-
     if(m_currentIndex < m_countMainView-1)
         setFileInFolderMainView(m_entriesMainView[index+1]);
     else if(m_countMainView > 1)
@@ -785,6 +833,10 @@ int PQCFileFolderModel::getCurrentIndex() {
     return m_currentIndex;
 }
 
+int PQCFileFolderModel::getCurrentIndexNoDelay() {
+    return m_currentIndexNoDelay;
+}
+
 void PQCFileFolderModel::setCurrentIndex(int val) {
 
     if(m_currentIndex != val) {
@@ -794,36 +846,16 @@ void PQCFileFolderModel::setCurrentIndex(int val) {
         else
             m_currentFile = m_entriesMainView[m_currentIndex];
 
-        Q_EMIT currentIndexChanged();
-        Q_EMIT currentFileChanged();
+        m_currentIndexNoDelay = m_currentIndex;
+        m_currentFileNoDelay = m_currentFile;
+
+        Q_EMIT currentIndexNoDelayChanged();
+        Q_EMIT currentFileNoDelayChanged();
+
+        timerNotifyCurrentIndexChanged->start();
 
     }
 
-    bool ispdf = m_currentFile.indexOf("::PDF::")>-1;
-    if(m_isPDF != ispdf) {
-        m_isPDF = ispdf;
-        m_isARC = false;
-        if(ispdf) {
-            m_pdfName = m_currentFile.split("::PDF::")[1];
-            m_pdfNum = m_currentFile.split("::PDF::")[0].toInt();
-        }
-        Q_EMIT isPDFChanged();
-        Q_EMIT pdfNameChanged();
-        Q_EMIT pdfNumChanged();
-    }
-
-    bool isarc = m_currentFile.indexOf("::ARC::")>-1;
-    if(m_isARC != isarc) {
-        m_isPDF = false;
-        m_isARC = isarc;
-        if(m_isARC) {
-            m_arcName = m_currentFile.split("::ARC::")[1];
-            m_arcFile = m_currentFile.split("::ARC::")[0];
-        }
-        Q_EMIT isARCChanged();
-        Q_EMIT arcNameChanged();
-        Q_EMIT arcFileChanged();
-    }
 
 }
 
@@ -831,6 +863,10 @@ QString PQCFileFolderModel::getCurrentFile() {
     return m_currentFile;
 }
 
+QString PQCFileFolderModel::getCurrentFileNoDelay() {
+    return m_currentFileNoDelay;
+}
+
 bool PQCFileFolderModel::getIsPDF() {
     return m_isPDF;
 }
@@ -877,10 +913,14 @@ void PQCFileFolderModel::loadDataMainView() {
     if(m_fileInFolderMainView.isEmpty()) {
         m_currentFile = "";
         m_currentIndex = -1;
+        m_currentIndexNoDelay = -1;
+        m_currentFileNoDelay = "";
         Q_EMIT newDataLoadedMainView();
         Q_EMIT countMainViewChanged();
         Q_EMIT currentFileChanged();
         Q_EMIT currentIndexChanged();
+        Q_EMIT currentFileNoDelayChanged();
+        Q_EMIT currentIndexNoDelayChanged();
         return;
     }
 
@@ -949,10 +989,15 @@ void PQCFileFolderModel::loadDataMainView() {
         m_currentIndex = m_entriesMainView.indexOf(m_fileInFolderMainView);
         m_currentFile = m_fileInFolderMainView;
 
+        m_currentIndexNoDelay = m_currentIndex;
+        m_currentFileNoDelay = m_currentFile;
+
         Q_EMIT newDataLoadedMainView();
         Q_EMIT countMainViewChanged();
         Q_EMIT currentIndexChanged();
         Q_EMIT currentFileChanged();
+        Q_EMIT currentIndexNoDelayChanged();
+        Q_EMIT currentFileNoDelayChanged();
 
     }
 
@@ -998,7 +1043,7 @@ void PQCFileFolderModel::loadDataFileDialog() {
     ////////////////////////
     // load files
 
-    m_entriesFileDialog.append(getAllFiles(m_folderFileDialog, true));
+    m_entriesFileDialog.append(getAllFiles(m_folderFileDialog, true, true));
 
     m_countFilesFileDialog = m_entriesFileDialog.length()-m_countFoldersFileDialog;
 
@@ -1018,9 +1063,14 @@ QStringList PQCFileFolderModel::getAllFolders(QString folder, bool forceShowHidd
     QStringList ret;
 
     const bool sortReversed = !PQCSettings::get()["imageviewSortImagesAscending"].toBool();
-    const QString sortBy = PQCSettings::get()["imageviewSortImagesBy"].toString();
+    QString sortBy = PQCSettings::get()["imageviewSortImagesBy"].toString();
     const bool showHidden = (PQCSettings::get()["filedialogShowHiddenFilesFolders"].toBool() || forceShowHidden);
 
+#ifdef PQMWITHOUTICU
+    if(sortBy == "naturalname")
+        sortBy = "name";
+#endif
+
     QDir::SortFlags sortFlags = QDir::IgnoreCase;
     if(sortReversed)
         sortFlags |= QDir::Reversed;
@@ -1033,7 +1083,7 @@ QStringList PQCFileFolderModel::getAllFolders(QString folder, bool forceShowHidd
     else if(sortBy == "type")
         sortFlags |= QDir::Type;
 
-    if(!cache.loadFoldersFromCache(folder, showHidden, sortFlags, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, false, ret)) {
+    if(!cache.loadFoldersFromCache(folder, showHidden, sortReversed, sortBy, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, false, ret)) {
 
         QDir dir(folder);
 
@@ -1063,7 +1113,7 @@ QStringList PQCFileFolderModel::getAllFolders(QString folder, bool forceShowHidd
                 std::sort(ret.begin(), ret.end(), [&collator](const QString &file1, const QString &file2) { return collator.compare(file1, file2) < 0; });
         }
 
-        cache.saveFoldersToCache(folder, showHidden, sortFlags, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, false, ret);
+        cache.saveFoldersToCache(folder, showHidden, sortReversed, sortBy, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, false, ret);
 
     }
 
@@ -1071,7 +1121,7 @@ QStringList PQCFileFolderModel::getAllFolders(QString folder, bool forceShowHidd
 
 }
 
-QStringList PQCFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersExceptDefault) {
+QStringList PQCFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersExceptDefault, bool enforceOnlyIncludingThisFolder) {
 
     qDebug() << "args: folder =" << folder;
     qDebug() << "args: ignoreFiltersExceptDefault =" << ignoreFiltersExceptDefault;
@@ -1079,9 +1129,14 @@ QStringList PQCFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersEx
     QStringList ret;
 
     const bool sortReversed = !PQCSettings::get()["imageviewSortImagesAscending"].toBool();
-    const QString sortBy = PQCSettings::get()["imageviewSortImagesBy"].toString();
+    QString sortBy = PQCSettings::get()["imageviewSortImagesBy"].toString();
     const bool showHidden = PQCSettings::get()["filedialogShowHiddenFilesFolders"].toBool();
 
+#ifdef PQMWITHOUTICU
+    if(sortBy == "naturalname")
+        sortBy = "name";
+#endif
+
     QDir::SortFlags sortFlags = QDir::IgnoreCase;
     if(sortReversed)
         sortFlags |= QDir::Reversed;
@@ -1100,23 +1155,29 @@ QStringList PQCFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersEx
     QStringList foldersToScan;
     foldersToScan << folder;
 
-    if(m_includeFilesInSubFolders) {
-        QDirIterator iter(folder, QDir::Dirs|QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
-        int count = 0;
-        while(iter.hasNext()) {
-            iter.next();
-            foldersToScan << iter.filePath();
+    if(!enforceOnlyIncludingThisFolder) {
 
-            // we limit the number of subfolders to avoid getting stuck
-            ++count;
-            if(count > 100)
-                break;
+        if(m_includeFilesInSubFolders) {
+            QDirIterator iter(folder, QDir::Dirs|QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
+            int count = 0;
+            while(iter.hasNext()) {
+                iter.next();
+                foldersToScan << iter.filePath();
+
+                // we limit the number of subfolders to avoid getting stuck
+                ++count;
+                if(count > 100)
+                    break;
+            }
+        } else if(m_extraFoldersToLoad.length() > 0) {
+            foldersToScan.append(m_extraFoldersToLoad);
         }
+
     }
 
     for(const QString &f : std::as_const(foldersToScan)) {
 
-        if(!cache.loadFilesFromCache(f, showHidden, sortFlags, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, ignoreFiltersExceptDefault, PQCImageFormats::get().getEnabledFormatsNum(), ret)) {
+        if(!cache.loadFilesFromCache(f, showHidden, sortReversed, sortBy, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, ignoreFiltersExceptDefault, PQCImageFormats::get().getEnabledFormatsNum(), ret)) {
 
             QStringList ret_cur;
 
@@ -1238,7 +1299,7 @@ QStringList PQCFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersEx
             // add current list, sorted, to global result list
             ret << ret_cur;
 
-            cache.saveFilesToCache(f, showHidden, sortFlags, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, ignoreFiltersExceptDefault, PQCImageFormats::get().getEnabledFormatsNum(), ret_cur);
+            cache.saveFilesToCache(f, showHidden, sortReversed, sortBy, m_restrictToSuffixes, m_nameFilters, m_filenameFilters, m_restrictToMimeTypes, m_imageResolutionFilter, m_fileSizeFilter, ignoreFiltersExceptDefault, PQCImageFormats::get().getEnabledFormatsNum(), ret_cur);
 
         }
 
@@ -1349,6 +1410,12 @@ void PQCFileFolderModel::disableViewerMode() {
     else if(tmp.contains("::ARC::"))
         setFileInFolderMainView(tmp.split("::ARC::")[1]);
     forceReloadMainView();
+
+    m_isPDF = false;
+    m_isARC = false;
+    Q_EMIT isARCChanged();
+    Q_EMIT isPDFChanged();
+
 }
 
 QString PQCFileFolderModel::getFirstMatchFileDialog(QString partial) {
@@ -1367,7 +1434,7 @@ QString PQCFileFolderModel::getFirstMatchFileDialog(QString partial) {
 
     }
 
-    QStringList files = getAllFiles(parent, true);
+    QStringList files = getAllFiles(parent, true, true);
 
     for(const auto &f : std::as_const(files)) {
         if(f.sliced(parent.length()).startsWith(typed))
