@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -83,7 +83,9 @@ PQCScriptsConfig::PQCScriptsConfig() {
     currentTranslation = "en";
 }
 
-PQCScriptsConfig::~PQCScriptsConfig() {}
+PQCScriptsConfig::~PQCScriptsConfig() {
+    delete trans;
+}
 
 bool PQCScriptsConfig::amIOnWindows() {
 #ifdef Q_OS_WIN
@@ -216,10 +218,10 @@ bool PQCScriptsConfig::exportConfigTo(QString path) {
 
     // All the config files
     QHash<QString,QString> allfiles;
-    allfiles["CFG_SETTINGS_DB"] = PQCConfigFiles::SETTINGS_DB();
-    allfiles["CFG_IMAGEFORMATS_DB"] = PQCConfigFiles::IMAGEFORMATS_DB();
-    allfiles["CFG_CONTEXTMENU_DB"] = PQCConfigFiles::CONTEXTMENU_DB();
-    allfiles["CFG_SHORTCUTS_DB"] = PQCConfigFiles::SHORTCUTS_DB();
+    allfiles["CFG_SETTINGS_DB"] = PQCConfigFiles::get().SETTINGS_DB();
+    allfiles["CFG_IMAGEFORMATS_DB"] = PQCConfigFiles::get().IMAGEFORMATS_DB();
+    allfiles["CFG_CONTEXTMENU_DB"] = PQCConfigFiles::get().CONTEXTMENU_DB();
+    allfiles["CFG_SHORTCUTS_DB"] = PQCConfigFiles::get().SHORTCUTS_DB();
 
     // handler to the file
     struct archive *a = archive_write_new();
@@ -304,10 +306,10 @@ bool PQCScriptsConfig::importConfigFrom(QString path) {
 
     // All the config files to be imported
     QHash<QString,QString> allfiles;
-    allfiles["CFG_SETTINGS_DB"] = PQCConfigFiles::SETTINGS_DB();
-    allfiles["CFG_CONTEXTMENU_DB"] = PQCConfigFiles::CONTEXTMENU_DB();
-    allfiles["CFG_SHORTCUTS_DB"] = PQCConfigFiles::SHORTCUTS_DB();
-    allfiles["CFG_IMAGEFORMATS_DB"] = PQCConfigFiles::IMAGEFORMATS_DB();
+    allfiles["CFG_SETTINGS_DB"] = PQCConfigFiles::get().SETTINGS_DB();
+    allfiles["CFG_CONTEXTMENU_DB"] = PQCConfigFiles::get().CONTEXTMENU_DB();
+    allfiles["CFG_SHORTCUTS_DB"] = PQCConfigFiles::get().SHORTCUTS_DB();
+    allfiles["CFG_IMAGEFORMATS_DB"] = PQCConfigFiles::get().IMAGEFORMATS_DB();
 
     // Create new archive handler
     struct archive *a = archive_read_new();
@@ -317,7 +319,11 @@ bool PQCScriptsConfig::importConfigFrom(QString path) {
     archive_read_support_filter_all(a);
 
     // Read file - if something went wrong, output error message and stop here
+#ifdef Q_OS_WIN
+    int r = archive_read_open_filename_w(a, reinterpret_cast<const wchar_t*>(archiveFile.utf16()), 10240);
+#else
     int r = archive_read_open_filename(a, archiveFile.toLocal8Bit().data(), 10240);
+#endif
     if(r != ARCHIVE_OK) {
         qWarning() << "ERROR: archive_read_open_filename() returned code of" << r;
         return false;
@@ -426,7 +432,7 @@ QString PQCScriptsConfig::getLastLoadedImage() {
 
     QString ret = "";
 
-    QFile file(PQCConfigFiles::LASTOPENEDIMAGE_FILE());
+    QFile file(PQCConfigFiles::get().LASTOPENEDIMAGE_FILE());
     if(file.open(QIODevice::ReadOnly)) {
         QTextStream in(&file);
         ret = in.readAll();
@@ -441,7 +447,7 @@ void PQCScriptsConfig::setLastLoadedImage(QString path) {
 
     qDebug() << "args: path =" << path;
 
-    QFile file(PQCConfigFiles::LASTOPENEDIMAGE_FILE());
+    QFile file(PQCConfigFiles::get().LASTOPENEDIMAGE_FILE());
     if(file.open(QIODevice::WriteOnly|QIODevice::Truncate)) {
         QTextStream out(&file);
         out << path;
@@ -457,7 +463,7 @@ void PQCScriptsConfig::deleteLastLoadedImage() {
 
     // attempts to remove stored last loaded image
     // not a big deal if this fails thus no need to error check
-    QFile file(PQCConfigFiles::LASTOPENEDIMAGE_FILE());
+    QFile file(PQCConfigFiles::get().LASTOPENEDIMAGE_FILE());
     if(file.exists())
         file.remove();
 
@@ -554,23 +560,26 @@ QStringList PQCScriptsConfig::getAvailableTranslations() {
 
 void PQCScriptsConfig::updateTranslation() {
 
+    qDebug() << "";
+
     QString code = PQCSettings::get()["interfaceLanguage"].toString();
     if(code == currentTranslation)
         return;
 
-    if(!trans->isEmpty())
-        qApp->removeTranslator(trans);
-
+    static QTranslator trans;
+    qApp->removeTranslator(&trans);
 
     const QStringList allcodes = code.split("/");
 
+    // we use this to detect whether a translation was found for the above language code
+    currentTranslation = "";
     for(const QString &c : allcodes) {
 
         if(QFile(":/lang/photoqt_" + c + ".qm").exists()) {
 
-            if(trans->load(":/lang/photoqt_" + c)) {
+            if(trans.load(":/lang/photoqt_" + c)) {
                 currentTranslation = c;
-                qApp->installTranslator(trans);
+                qApp->installTranslator(&trans);
             } else
                 qWarning() << "Unable to install translator for language code" << c;
 
@@ -580,9 +589,9 @@ void PQCScriptsConfig::updateTranslation() {
 
             if(QFile(":/lang/photoqt_" + cc + ".qm").exists()) {
 
-                if(trans->load(":/lang/photoqt_" + cc)) {
+                if(trans.load(":/lang/photoqt_" + cc)) {
                     currentTranslation = cc;
-                    qApp->installTranslator(trans);
+                    qApp->installTranslator(&trans);
                 } else
                     qWarning() << "Unable to install translator for language code" << cc;
 
@@ -594,9 +603,9 @@ void PQCScriptsConfig::updateTranslation() {
 
             if(QFile(":/lang/photoqt_" + cc + ".qm").exists()) {
 
-                if(trans->load(":/lang/photoqt_" + cc)) {
+                if(trans.load(":/lang/photoqt_" + cc)) {
                     currentTranslation = cc;
-                    qApp->installTranslator(trans);
+                    qApp->installTranslator(&trans);
                 } else
                     qWarning() << "Unable to install translator for language code" << c;
 
@@ -605,6 +614,10 @@ void PQCScriptsConfig::updateTranslation() {
 
     }
 
+    // no translation found -> store selected code
+    if(currentTranslation == "")
+        currentTranslation = code;
+
     QQmlEngine::contextForObject(this)->engine()->retranslate();
 
 }
@@ -648,3 +661,14 @@ bool PQCScriptsConfig::isLCMS2SupportEnabled() {
 #endif
     return false;
 }
+
+void PQCScriptsConfig::setDefaultSettingValueFor(QString key) {
+    PQCSettings::get().setDefaultFor(key);
+}
+
+bool PQCScriptsConfig::isICUSupportEnabled() {
+#ifdef PQMWITHOUTICU
+    return false;
+#endif
+    return true;
+}
