@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -30,6 +30,7 @@
 #include <QJSValue>
 #include <QJSEngine>
 #include <QtConcurrent>
+#include <pqc_settings.h>
 
 #ifdef PQMPUGIXML
 #include <pugixml.hpp>
@@ -53,6 +54,11 @@ QVariantList PQCScriptsFileDialog::getDevices() {
     for(const QStorageInfo &s : info) {
         if(s.isValid()) {
 
+            const QString tpe = QString(s.fileSystemType());
+
+            if((tpe.toLower() == "tmpfs" || tpe.toLower() == "squashfs") && !PQCSettings::get()["filedialogDevicesShowTmpfs"].toBool())
+                continue;
+
             QString name = s.name();
             if(name == "")
                 name = QDir::toNativeSeparators(s.rootPath());
@@ -62,7 +68,7 @@ QVariantList PQCScriptsFileDialog::getDevices() {
             QVariantList vol;
             vol << name
                 << s.bytesTotal()
-                << QString(s.fileSystemType())
+                << tpe
                 << p;
 
             ret.append(vol);
@@ -83,13 +89,15 @@ QVariantList PQCScriptsFileDialog::getPlaces(bool performEmptyCheck) {
 #ifdef PQMPUGIXML
 
     // if file does not exist yet then we create a sceleton file
-    if(!QFile(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel")).exists()) {
+    if(!QFile(PQCConfigFiles::get().USER_PLACES_XBEL()).exists()) {
+
+        qDebug() << "Loading default user_places.xbel file";
 
         QString cont = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
         cont += "<xbel xmlns:mime=\"http://www.freedesktop.org/standards/shared-mime-info\" xmlns:bookmark=\"http://www.freedesktop.org/standards/desktop-bookmarks\">\n";
         cont += "</xbel>";
 
-        QFile file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel"));
+        QFile file(PQCConfigFiles::get().USER_PLACES_XBEL());
         if(file.open(QIODevice::WriteOnly)) {
             QTextStream out(&file);
             out << cont;
@@ -98,7 +106,7 @@ QVariantList PQCScriptsFileDialog::getPlaces(bool performEmptyCheck) {
     }
 
     pugi::xml_document doc;
-    pugi::xml_parse_result result = doc.load_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8());
+    pugi::xml_parse_result result = doc.load_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8());
     if(!result) {
         qWarning() << "Unable to read user places. Either file doesn't exist (yet) or cannot be read...";
         return ret;
@@ -116,20 +124,29 @@ QVariantList PQCScriptsFileDialog::getPlaces(bool performEmptyCheck) {
 
         QString path = QUrl::fromPercentEncoding(bm.attribute("href").value());
 
-// we need to check for the old (wrong) syntax of two slashes
-// and for the new right synbtax of three slashes after file:
+// we need to check for the old syntax of two/three slashes
 #ifdef Q_OS_WIN
         if(path.startsWith("file:///"))
             path = path.remove(0,8);
         else if(path.startsWith("file://"))
             path = path.remove(0,7);
+        else if(path.startsWith("file:/"))
+            path = path.remove(0,6);
+        else if(path.startsWith("file:"))
+            path = path.remove(0,5);
 #else
         if(path.startsWith("file:////"))
             path = path.remove(0,8);
         else if(path.startsWith("file:///"))
             path = path.remove(0,7);
-        else if(path == "trash:/")
-            path = PQCConfigFiles::GENERIC_DATA_DIR() + "/Trash/files";
+        else if(path.startsWith("file://"))
+            path = path.remove(0,6);
+        else if(path.startsWith("file:/"))
+            path = path.remove(0,5);
+        else if(path.startsWith("file:"))
+            path = path.remove(0,4);
+        else if(path == "trash:/" || path == "trash:")
+            path = PQCConfigFiles::get().USER_TRASH_FILES();
 #endif
         else
             continue;
@@ -190,7 +207,7 @@ QVariantList PQCScriptsFileDialog::getPlaces(bool performEmptyCheck) {
     }
 
     if(docUpdated)
-        doc.save_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8(), " ");
+        doc.save_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8(), " ");
 
 #endif
 
@@ -234,7 +251,7 @@ QString PQCScriptsFileDialog::getUniquePlacesId() {
 #ifdef PQMPUGIXML
 
     pugi::xml_document doc;
-    pugi::xml_parse_result result = doc.load_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8());
+    pugi::xml_parse_result result = doc.load_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8());
     if(!result) {
         qWarning() << "Unable to read user places. Either file doesn't exist (yet) or cannot be read...";
         return "";
@@ -247,7 +264,7 @@ QString PQCScriptsFileDialog::getUniquePlacesId() {
         pugi::xml_node cur = node.node();
         QString curId = cur.select_node("info/metadata/ID").node().child_value();
         QString curPath = QUrl::fromPercentEncoding(cur.attribute("href").value());
-        if(curPath.startsWith("file:/") || curPath == "trash:/")
+        if(curPath.startsWith("file:") || curPath == "trash:" || curPath == "trash:/")
             allIds.append(curId);
     }
 
@@ -269,7 +286,7 @@ bool PQCScriptsFileDialog::setLastLocation(QString path) {
 
     qDebug() << "args: path =" << path;
 
-    QFile file(PQCConfigFiles::FILEDIALOG_LAST_LOCATION());
+    QFile file(PQCConfigFiles::get().FILEDIALOG_LAST_LOCATION());
     if(file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
         QTextStream out(&file);
         out << path;
@@ -331,7 +348,7 @@ QString PQCScriptsFileDialog::getLastLocation() {
     qDebug() << "";
 
     QString ret = QDir::currentPath();
-    QFile file(PQCConfigFiles::FILEDIALOG_LAST_LOCATION());
+    QFile file(PQCConfigFiles::get().FILEDIALOG_LAST_LOCATION());
     if(file.exists() && file.open(QIODevice::ReadOnly)) {
         QTextStream in(&file);
         ret = in.readAll().trimmed();
@@ -353,7 +370,7 @@ void PQCScriptsFileDialog::movePlacesEntry(QString id, bool moveDown, int howman
 #ifdef PQMPUGIXML
 
     pugi::xml_document doc;
-    pugi::xml_parse_result result = doc.load_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8());
+    pugi::xml_parse_result result = doc.load_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8());
     if(!result) {
         qWarning() << "ERROR: Unable to read user places. Either file doesn't exist (yet) or cannot be read...";
         return;
@@ -367,7 +384,7 @@ void PQCScriptsFileDialog::movePlacesEntry(QString id, bool moveDown, int howman
         pugi::xml_node cur = node.node();
         QString curId = cur.select_node("info/metadata/ID").node().child_value();
         QString curPath = QUrl::fromPercentEncoding(cur.attribute("href").value());
-        if(curPath.startsWith("file:/") || curPath == "trash:/")
+        if(curPath.startsWith("file:") || curPath == "trash:" || curPath == "trash:/")
             allIds.append(curId);
     }
 
@@ -412,7 +429,7 @@ void PQCScriptsFileDialog::movePlacesEntry(QString id, bool moveDown, int howman
 
     }
 
-    doc.save_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8(), " ");
+    doc.save_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8(), " ");
 
 #endif
 
@@ -429,7 +446,7 @@ void PQCScriptsFileDialog::addPlacesEntry(QString path, int pos, QString titlest
 #ifdef PQMPUGIXML
 
     pugi::xml_document doc;
-    pugi::xml_parse_result result = doc.load_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8());
+    pugi::xml_parse_result result = doc.load_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8());
     if(!result) {
         qWarning() << "ERROR: Unable to read user places. Either file doesn't exist (yet) or cannot be read...";
         return;
@@ -444,7 +461,7 @@ void PQCScriptsFileDialog::addPlacesEntry(QString path, int pos, QString titlest
 
         QString path = cur.attribute("href").value();
 
-        if(path == "trash:/" || path.startsWith("file:/"))
+        if(path == "trash:" || path == "trash:/" || path.startsWith("file:"))
             allIds.push_back(cur.select_node("info/metadata/ID").node().child_value());
 
     }
@@ -455,7 +472,7 @@ void PQCScriptsFileDialog::addPlacesEntry(QString path, int pos, QString titlest
     while(allIds.contains(QString("%1/%2").arg(newid_base).arg(counter)))
         ++counter;
 
-    // no items currenty set
+    // no items currently set
     if(allIds.length() == 0) {
 
         pugi::xpath_node_set toplevel = doc.select_nodes("/xbel");
@@ -467,7 +484,7 @@ void PQCScriptsFileDialog::addPlacesEntry(QString path, int pos, QString titlest
         // <bookmark>
         newnode.set_name("bookmark");
         newnode.append_attribute("href");
-        newnode.attribute("href").set_value(QString("file:///%1").arg(QString::fromLatin1(QUrl::toPercentEncoding(path))).toStdString().c_str());
+        newnode.attribute("href").set_value(QString("file:%1").arg(QString::fromLatin1(QUrl::toPercentEncoding(path))).toStdString().c_str());
 
         // <title>
         pugi::xml_node title = newnode.append_child("title");
@@ -520,7 +537,7 @@ void PQCScriptsFileDialog::addPlacesEntry(QString path, int pos, QString titlest
                 // <bookmark>
                 newnode.set_name("bookmark");
                 newnode.append_attribute("href");
-                newnode.attribute("href").set_value(QString("file:///%1").arg(QString::fromLatin1(QUrl::toPercentEncoding(path))).toStdString().c_str());
+                newnode.attribute("href").set_value(QString("file:%1").arg(QString::fromLatin1(QUrl::toPercentEncoding(path))).toStdString().c_str());
 
                 // <title>
                 pugi::xml_node title = newnode.append_child("title");
@@ -564,7 +581,7 @@ void PQCScriptsFileDialog::addPlacesEntry(QString path, int pos, QString titlest
 
     }
 
-    doc.save_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8(), " ");
+    doc.save_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8(), " ");
 
 #endif
 
@@ -578,7 +595,7 @@ void PQCScriptsFileDialog::hidePlacesEntry(QString id, bool hidden) {
 #ifdef PQMPUGIXML
 
     pugi::xml_document doc;
-    pugi::xml_parse_result result = doc.load_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8());
+    pugi::xml_parse_result result = doc.load_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8());
     if(!result) {
         qWarning() << "ERROR: Unable to read user places. Either file doesn't exist (yet) or cannot be read...";
         return;
@@ -603,7 +620,7 @@ void PQCScriptsFileDialog::hidePlacesEntry(QString id, bool hidden) {
         }
     }
 
-    doc.save_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8(), " ");
+    doc.save_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8(), " ");
 
 #endif
 
@@ -616,7 +633,7 @@ void PQCScriptsFileDialog::deletePlacesEntry(QString id) {
 #ifdef PQMPUGIXML
 
     pugi::xml_document doc;
-    pugi::xml_parse_result result = doc.load_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8());
+    pugi::xml_parse_result result = doc.load_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8());
     if(!result) {
         qWarning() << "ERROR: Unable to read user places. Either file doesn't exist (yet) or cannot be read...";
         return;
@@ -636,7 +653,7 @@ void PQCScriptsFileDialog::deletePlacesEntry(QString id) {
         }
     }
 
-    doc.save_file(QString(PQCConfigFiles::GENERIC_DATA_DIR() + "/user-places.xbel").toUtf8(), " ");
+    doc.save_file(PQCConfigFiles::get().USER_PLACES_XBEL().toUtf8(), " ");
 
 #endif
 
