@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -54,6 +54,8 @@ QString PQCScriptsFilesPaths::cleanPath(QString path) {
         path = path.remove(0, 7);
     else if(path.startsWith("file://"))
         path = path.remove(0, 6);
+    else if(path.startsWith("file:/"))
+        path = path.remove(0, 5);
     else if(path.startsWith("image://full/"))
         path = path.remove(0, 13);
     else if(path.startsWith("image://thumb/"))
@@ -76,6 +78,8 @@ QString PQCScriptsFilesPaths::cleanPath_windows(QString path) {
         path = path.remove(0, 7);
     else if(path.startsWith("file:/"))
         path = path.remove(0, 6);
+    else if(path.startsWith("file:"))
+        path = path.remove(0, 5);
     else if(path.startsWith("image://full/"))
         path = path.remove(0, 13);
     else if(path.startsWith("image://thumb/"))
@@ -85,7 +89,15 @@ QString PQCScriptsFilesPaths::cleanPath_windows(QString path) {
     if(info.isSymLink() && info.exists())
         path = info.symLinkTarget();
 
-    return QDir::cleanPath(path);
+    bool addslash = false;
+    if(path.startsWith("//"))
+        addslash = true;
+
+    path = QDir::cleanPath(path);
+    if(addslash)
+        path = "/"+path;
+
+    return path;
 
 }
 
@@ -220,7 +232,9 @@ QStringList PQCScriptsFilesPaths::getFoldersIn(QString path) {
     QStringList ret = dir.entryList();
 
     QCollator collator;
+#ifndef PQMWITHOUTICU
     collator.setNumericMode(true);
+#endif
     std::sort(ret.begin(), ret.end(), [&collator](const QString &file1, const QString &file2) { return collator.compare(file1, file2) < 0; });
 
     return ret;
@@ -262,7 +276,7 @@ bool PQCScriptsFilesPaths::isExcludeDirFromCaching(QString filename) {
 
     const QStringList str = PQCSettings::get()["thumbnailsExcludeFolders"].toStringList();
     for(const QString &dir: str) {
-        if(filename.indexOf(dir) == 0)
+        if(dir != "" && filename.indexOf(dir) == 0)
             return true;
     }
 
@@ -378,6 +392,36 @@ QString PQCScriptsFilesPaths::selectFileFromDialog(QString buttonlabel, QString
 
 }
 
+QString PQCScriptsFilesPaths::selectFolderFromDialog(QString buttonlabel, QString preselectFolder) {
+
+    qDebug() << "args: buttonlabel" << buttonlabel;
+    qDebug() << "args: preselectFolder" << preselectFolder;
+
+    QFileInfo info(preselectFolder);
+
+    PQCNotify::get().setModalFileDialogOpen(true);
+
+    QFileDialog diag;
+    diag.setLabelText(QFileDialog::Accept, buttonlabel);
+    diag.setFileMode(QFileDialog::Directory);
+    diag.setModal(true);
+    diag.setOption(QFileDialog::DontUseNativeDialog, false);
+    diag.setDirectory(preselectFolder);
+    diag.selectFile(info.baseName());
+
+    if(diag.exec()) {
+        QStringList fileNames = diag.selectedFiles();
+        if(fileNames.length() > 0) {
+            PQCNotify::get().setModalFileDialogOpen(false);
+            return fileNames[0];
+        }
+    }
+
+    PQCNotify::get().setModalFileDialogOpen(false);
+    return "";
+
+}
+
 void PQCScriptsFilesPaths::saveLogToFile(QString txt) {
 
     qDebug() << "args: txt.length = " << txt.length();
@@ -536,7 +580,7 @@ QString PQCScriptsFilesPaths::findDropBoxFolder() {
 
 #ifdef Q_OS_UNIX
     QFile f(QDir::homePath()+"/.dropbox/host.db");
-#elif defined Q_OS_WIN
+#else
     QFile f(QString("%1/Dropbox/host.db").arg(QStandardPaths::AppDataLocation));
 #endif
     if(f.exists()) {
@@ -624,12 +668,12 @@ QString PQCScriptsFilesPaths::handleAnimatedImagePathAndEncode(QString path) {
     if(info.size() > 1024*1024*256)
         return toPercentEncoding(path);
 
-    const QString tempdir = QString("%1/animatedfiles").arg(PQCConfigFiles::CACHE_DIR());
+    const QString tempdir = QString("%1/animatedfiles").arg(PQCConfigFiles::get().CACHE_DIR());
     QDir dir(tempdir);
     if(!dir.exists())
         dir.mkdir(tempdir);
 
-    QString targetFilename = QString("%1/animatedfiles/temp%3.%4").arg(PQCConfigFiles::CACHE_DIR()).arg(animatedImageTemporaryCounter).arg(info.suffix());
+    QString targetFilename = QString("%1/animatedfiles/temp%3.%4").arg(PQCConfigFiles::get().CACHE_DIR()).arg(animatedImageTemporaryCounter).arg(info.suffix());
     QFileInfo targetinfo(targetFilename);
 
     animatedImageTemporaryCounter = (animatedImageTemporaryCounter+1)%5;
@@ -655,15 +699,19 @@ QString PQCScriptsFilesPaths::handleAnimatedImagePathAndEncode(QString path) {
 
 void PQCScriptsFilesPaths::cleanupTemporaryFiles() {
 
-    QDir dir(QString("%1/animatedfiles").arg(PQCConfigFiles::CACHE_DIR()));
+    QDir dir(QString("%1/animatedfiles").arg(PQCConfigFiles::get().CACHE_DIR()));
     if(dir.exists())
         dir.removeRecursively();
 
-    dir.setPath(PQCConfigFiles::CACHE_DIR() + "/archive/");
+    dir.setPath(PQCConfigFiles::get().CACHE_DIR() + "/archive/");
     if(dir.exists())
         dir.removeRecursively();
 
-    dir.setPath(PQCConfigFiles::CACHE_DIR() + "/motionphotos/");
+    dir.setPath(PQCConfigFiles::get().CACHE_DIR() + "/clipboard/");
+    if(dir.exists())
+        dir.removeRecursively();
+
+    dir.setPath(PQCConfigFiles::get().CACHE_DIR() + "/motionphotos/");
     if(dir.exists())
         dir.removeRecursively();
 
@@ -674,3 +722,11 @@ bool PQCScriptsFilesPaths::isUrl(QString path) {
     return (path.startsWith("http://") || path.startsWith("https://") || path.startsWith("ftp://") || path.startsWith("ftps://"));
 
 }
+
+void PQCScriptsFilesPaths::setThumbnailBaseCacheDir(QString dir) {
+
+    qDebug() << "args dir =" << dir;
+
+    PQCConfigFiles::get().setThumbnailCacheBaseDir(dir);
+
+}
