@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -33,6 +33,7 @@
 #include <QMediaPlayer>
 #include <QColorSpace>
 #include <QFileDialog>
+#include <QScreen>
 #include <scripts/pqc_scriptsimages.h>
 #include <scripts/pqc_scriptsfilespaths.h>
 #include <pqc_settings.h>
@@ -73,12 +74,18 @@
 
 PQCScriptsImages::PQCScriptsImages() {
     importedICCLastMod = 0;
-    colorlastlocation = new QFile(QString("%1/%2").arg(PQCConfigFiles::CACHE_DIR(), "colorlastlocation"));
+    colorlastlocation = new QFile(QString("%1/%2").arg(PQCConfigFiles::get().CACHE_DIR(), "colorlastlocation"));
 
     // if the formats changed then we can't rely on the archive cache anymore
     connect(&PQCImageFormats::get(), &PQCImageFormats::formatsUpdated, this, [=]() {archiveContentCache.clear();});
 
     loadColorProfileInfo();
+
+    lcms2CountFailedApplications = 0;
+
+    devicePixelRatioCached = 0;
+    devicePixelRatioCachedWhen = 0;
+
 }
 
 PQCScriptsImages::~PQCScriptsImages() {
@@ -106,17 +113,17 @@ QString PQCScriptsImages::getIconPathFromTheme(QString binary) {
         // Setup path (this is the most likely directory) and format (PNG)
         QString path = QIcon::themeSearchPaths().at(i) + "/hicolor/32x32/apps/" + binary.trimmed() + ".png";
         if(QFile(path).exists())
-            return "file:///" + path;
+            return "file:" + path;
         else {
             // Also check a smaller version
             path = path.replace("32x32","22x22");
             if(QFile(path).exists())
-                return "file:///" + path;
+                return "file:" + path;
             else {
                 // And check 24x24, if not in the two before, it most likely is in here (e.g., shotwell on my system)
                 path = path.replace("22x22","24x24");
                 if(QFile(path).exists())
-                    return "file:///" + path;
+                    return "file:" + path;
             }
         }
 
@@ -124,15 +131,15 @@ QString PQCScriptsImages::getIconPathFromTheme(QString binary) {
 
         path = path.replace("22x22","32x32").replace(".png",".svg");
         if(QFile(path).exists())
-            return "file:///" + path;
+            return "file:" + path;
         else {
             path = path.replace("32x32","22x22");
             if(QFile(path).exists())
-                return "file:///" + path;
+                return "file:" + path;
             else {
                 path = path.replace("22x22","24x24");
                 if(QFile(path).exists())
-                    return "file:///" + path;
+                    return "file:" + path;
             }
         }
 
@@ -235,7 +242,11 @@ QStringList PQCScriptsImages::listArchiveContent(QString path, bool insideFilena
         archive_read_support_format_all(a);
 
         // Read file
+#ifdef Q_OS_WIN
+        int r = archive_read_open_filename_w(a, reinterpret_cast<const wchar_t*>(info.absoluteFilePath().utf16()), 10240);
+#else
         int r = archive_read_open_filename(a, info.absoluteFilePath().toLocal8Bit().data(), 10240);
+#endif
 
         // If something went wrong, output error message and stop here
         if(r != ARCHIVE_OK) {
@@ -280,9 +291,11 @@ QStringList PQCScriptsImages::listArchiveContent(QString path, bool insideFilena
 #endif
 
     QCollator collator;
+#ifndef PQMWITHOUTICU
     collator.setCaseSensitivity(Qt::CaseInsensitive);
     collator.setIgnorePunctuation(true);
     collator.setNumericMode(true);
+#endif
 
     if(PQCSettings::get()["imageviewSortImagesAscending"].toBool())
         std::sort(ret.begin(), ret.end(), [&collator](const QString &file1, const QString &file2) { return collator.compare(file1, file2) < 0; });
@@ -523,8 +536,8 @@ int PQCScriptsImages::getNumberDocumentPages(QString path) {
     if(path.trimmed().isEmpty())
         return 0;
 
-    if(path.contains("::PQT::"))
-        path = path.split("::PQT::").at(1);
+    if(path.contains("::PDF::"))
+        path = path.split("::PDF::").at(1);
 
 #ifdef PQMPOPPLER
     std::unique_ptr<Poppler::Document> document = Poppler::Document::load(path);
@@ -669,7 +682,7 @@ QString PQCScriptsImages::extractMotionPhoto(QString path) {
     qDebug() << "args: path =" << path;
 
     // at this point we assume that the check for google motion photo has already been done
-    // and we wont need to check again
+    // and we won't need to check again
 
     // the approach taken in this function is inspired by the analysis found at:
     // https://linuxreviews.org/Google_Pixel_%22Motion_Photo%22
@@ -678,7 +691,7 @@ QString PQCScriptsImages::extractMotionPhoto(QString path) {
     if(!info.exists())
         return "";
 
-    const QString videofilename = QString("%1/motionphotos/%2.mp4").arg(PQCConfigFiles::CACHE_DIR(), info.baseName());
+    const QString videofilename = QString("%1/motionphotos/%2.mp4").arg(PQCConfigFiles::get().CACHE_DIR(), info.baseName());
     if(QFileInfo::exists(videofilename)) {
         return videofilename;
     }
@@ -883,6 +896,247 @@ QVariantList PQCScriptsImages::getZXingData(QString path) {
 
 }
 
+QString PQCScriptsImages::extractArchiveFileToTempLocation(QString path) {
+
+    qDebug() << "args: path =" << path;
+
+    QString ret = "";
+
+    if(!path.contains("::ARC::"))
+        return "";
+
+    QStringList parts = path.split("::ARC::");
+    QString archivefile = parts.at(1);
+    QString compressedFilename = parts.at(0);
+
+    QFileInfo info(archivefile);
+    const QString suffix = info.suffix().toLower();
+
+#ifndef Q_OS_WIN
+    if(PQCSettings::get()["filetypesExternalUnrar"].toBool() && (suffix == "cbr" || suffix == "rar")) {
+
+        QProcess which;
+        which.setStandardOutputFile(QProcess::nullDevice());
+        which.start("which", QStringList() << "unrar");
+        which.waitForFinished();
+
+        if(!which.exitCode()) {
+
+            qDebug() << "loading archive with unrar";
+
+            // we extract it to a temp location from where we can load it then
+            const QString tempdir = PQCConfigFiles::get().CACHE_DIR() + "/clipboard/";
+
+            QDir td;
+            if(!td.exists(tempdir))
+                td.mkpath(tempdir);
+
+            QProcess p;
+            p.start("unrar", QStringList() << "x" << "-y" << archivefile << compressedFilename << tempdir);
+            p.waitForFinished(15000);
+
+            return tempdir+compressedFilename;
+
+        } else
+            qWarning() << "unrar was not found in system path";
+
+    }
+#endif
+
+#ifdef PQMLIBARCHIVE
+
+    // Create new archive handler
+    struct archive *a = archive_read_new();
+
+    // We allow any type of compression and format
+    archive_read_support_filter_all(a);
+    archive_read_support_format_all(a);
+
+    // Read file
+#ifdef Q_OS_WIN
+    int r = archive_read_open_filename_w(a, reinterpret_cast<const wchar_t*>(archivefile.utf16()), 10240);
+#else
+    int r = archive_read_open_filename(a, archivefile.toLocal8Bit().data(), 10240);
+#endif
+
+    // If something went wrong, output error message and stop here
+    if(r != ARCHIVE_OK) {
+        qWarning() << QString("archive_read_open_filename() returned code of %1").arg(r);
+        return "";
+    }
+
+    // Loop over entries in archive
+    struct archive_entry *entry;
+    while(archive_read_next_header(a, &entry) == ARCHIVE_OK) {
+
+        // Read the current file entry
+        // We use the '_w' variant here, as otherwise on Windows this call causes a segfault when a file in an archive contains non-latin characters
+        QString filenameinside = QString::fromWCharArray(archive_entry_pathname_w(entry));
+
+        // If this is the file we are looking for:
+        if(filenameinside == compressedFilename || (compressedFilename == "" && QFileInfo(filenameinside).suffix() != "")) {
+
+            // Find out the size of the data
+            int64_t size = archive_entry_size(entry);
+
+            // Create a uchar buffer of that size to hold the image data
+            uchar *buff = new uchar[size];
+
+            // And finally read the file into the buffer
+            la_ssize_t r = archive_read_data(a, (void*)buff, size);
+
+            if(r != size || size == 0) {
+                qWarning() << QString("Failed to read image data, read size (%1) doesn't match expected size (%2)...").arg(r).arg(size);
+                return "";
+            }
+
+            // we extract it to a temp location from where we can load it then
+            const QString tempdir = PQCConfigFiles::get().CACHE_DIR() + "/clipboard/";
+            const QString temppath = tempdir + filenameinside;
+
+            QDir td;
+            if(!td.exists(tempdir))
+                td.mkpath(tempdir);
+
+            // file handles
+            QFile file(temppath);
+            QFileInfo info(file);
+
+            // remove it if it exists, there is no way to know if it's the same file or not
+            if(file.exists()) file.remove();
+
+            // make sure the path exists
+            QDir dir(info.absolutePath());
+            if(!dir.exists())
+                dir.mkpath(info.absolutePath());
+
+            // write buffer to file
+            file.open(QIODevice::WriteOnly);
+            QDataStream out(&file);   // we will serialize the data into the file
+            out.writeRawData((const char*) buff,size);
+            file.close();
+            delete[] buff;
+
+            ret = temppath;
+
+            break;
+
+        }
+
+    }
+
+    // Close archive
+    r = archive_read_close(a);
+    if(r != ARCHIVE_OK)
+        qWarning() << "ERROR: archive_read_close() returned code of" << r;
+    r = archive_read_free(a);
+    if(r != ARCHIVE_OK)
+        qWarning() << "ERROR: archive_read_free() returned code of" << r;
+
+#endif
+
+    return ret;
+
+}
+
+QString PQCScriptsImages::extractDocumentPageToTempLocation(QString path) {
+
+    qDebug() << "args: path =" << path;
+
+    if(!path.contains("::PDF::"))
+        return "";
+
+    QString ret = "";
+
+#ifdef PQMQTPDF
+
+    // extract page and totalpage value from filename (prepended to filename (after filepath))
+    int page = path.split("::PDF::").at(0).toInt();
+    QString realFileName = path.split("::PDF::").at(1);
+
+    QPdfDocument doc;
+    doc.load(realFileName);
+
+    QPdfDocument::Error err = doc.error();
+    if(err != QPdfDocument::Error::None) {
+        qWarning() << "Error occurred loading PDF";
+        return "";
+    }
+
+    QSizeF _pageSize = (doc.pagePointSize(page)/72.0*qApp->primaryScreen()->physicalDotsPerInch())*(PQCSettings::get()["filetypesPDFQuality"].toDouble()/72.0);
+    QSize origSize = QSize(_pageSize.width(), _pageSize.height());
+
+    QImage p = doc.render(page, origSize);
+
+    if(p.isNull()) {
+        qWarning() << QString("Unable to read page %1").arg(page);
+        return "";
+    }
+
+    // some pdfs don't specify a background
+    // in that case the resulting image will have a transparent background
+    // to "fix" this we simply draw the image on top of a white image
+    QImage img(p.size(), p.format());
+    img.fill(Qt::white);
+    QPainter paint(&img);
+    paint.drawImage(QRect(QPoint(0,0), img.size()), p);
+    paint.end();
+
+    // we extract it to a temp location from where we can load it then
+    const QString tempdir = PQCConfigFiles::get().CACHE_DIR() + "/clipboard/";
+    const QString temppath = tempdir + QString("%1.jpg").arg(page+1);
+
+    QDir td;
+    if(!td.exists(tempdir))
+        td.mkpath(tempdir);
+
+    if(img.save(temppath)) {
+        return temppath;
+    }
+
+#endif
+#ifdef PQMPOPPLER
+
+    // extract page and totalpage value from filename (prepended to filename (after filepath))
+    int page = path.split("::PDF::").at(0).toInt();
+    QString filename = path.split("::PDF::").at(1);
+
+    // Load poppler document and render to QImage
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(filename);
+    if(!document || document->isLocked()) {
+        qWarning() << "Invalid PDF document, unable to load!";
+        return "";
+    }
+    document->setRenderHint(Poppler::Document::TextAntialiasing);
+    document->setRenderHint(Poppler::Document::Antialiasing);
+    std::unique_ptr<Poppler::Page> p = document->page(page);
+    if(p == nullptr) {
+        qWarning() << QString("Unable to read page %1").arg(page);
+        return "";
+    }
+
+    const double quality = PQCSettings::get()["filetypesPDFQuality"].toDouble();
+
+    QImage img = p->renderToImage(quality, quality);
+
+    // we extract it to a temp location from where we can load it then
+    const QString tempdir = PQCConfigFiles::get().CACHE_DIR() + "/clipboard/";
+    const QString temppath = tempdir + QString("%1.jpg").arg(page+1);
+
+    QDir td;
+    if(!td.exists(tempdir))
+        td.mkpath(tempdir);
+
+    if(img.save(temppath)) {
+        return temppath;
+    }
+
+#endif
+
+    return ret;
+
+}
+
 bool PQCScriptsImages::extractFrameAndSave(QString path, int frameNumber) {
 
     qDebug() << "args: path =" << path;
@@ -934,7 +1188,7 @@ int PQCScriptsImages::getDocumentPageCount(QString path) {
 
     QPdfDocument::Error err = doc.error();
     if(err != QPdfDocument::Error::None) {
-        qWarning() << "Error occured loading PDF";
+        qWarning() << "Error occurred loading PDF";
         return 0;
     }
 
@@ -977,7 +1231,7 @@ void PQCScriptsImages::loadColorProfileInfo() {
 
 #ifdef PQMLCMS2
 
-    QFileInfo info(PQCConfigFiles::ICC_COLOR_PROFILE_DIR());
+    QFileInfo info(PQCConfigFiles::get().ICC_COLOR_PROFILE_DIR());
     if(info.lastModified().toMSecsSinceEpoch() != importedICCLastMod) {
 
         // we always check for imported profile changes
@@ -986,12 +1240,12 @@ void PQCScriptsImages::loadColorProfileInfo() {
 
         importedICCLastMod = info.lastModified().toMSecsSinceEpoch();
 
-        QDir dir(PQCConfigFiles::ICC_COLOR_PROFILE_DIR());
+        QDir dir(PQCConfigFiles::get().ICC_COLOR_PROFILE_DIR());
         dir.setFilter(QDir::Files|QDir::NoDotAndDotDot);
         QStringList lst = dir.entryList();
         for(auto &f : std::as_const(lst)) {
 
-            QString fullpath = QString("%1/%2").arg(PQCConfigFiles::ICC_COLOR_PROFILE_DIR(), f);
+            QString fullpath = QString("%1/%2").arg(PQCConfigFiles::get().ICC_COLOR_PROFILE_DIR(), f);
 
             QFile file(fullpath);
 
@@ -1330,15 +1584,15 @@ bool PQCScriptsImages::importColorProfile() {
                 colorlastlocation->close();
             }
 
-            QDir dir(PQCConfigFiles::ICC_COLOR_PROFILE_DIR());
+            QDir dir(PQCConfigFiles::get().ICC_COLOR_PROFILE_DIR());
             if(!dir.exists()) {
-                if(!dir.mkpath(PQCConfigFiles::ICC_COLOR_PROFILE_DIR())) {
+                if(!dir.mkpath(PQCConfigFiles::get().ICC_COLOR_PROFILE_DIR())) {
                     qWarning() << "Unable to create internal ICC directory";
                     return false;
                 }
             }
 
-            if(!QFile::copy(fn,QString("%1/%2").arg(PQCConfigFiles::ICC_COLOR_PROFILE_DIR(), info.fileName()))) {
+            if(!QFile::copy(fn,QString("%1/%2").arg(PQCConfigFiles::get().ICC_COLOR_PROFILE_DIR(), info.fileName()))) {
                 qWarning() << "Unable to import file";
                 return false;
             }
@@ -1389,6 +1643,8 @@ bool PQCScriptsImages::applyColorProfile(QString filename, QImage &img) {
 
     bool manualSelectionCausedError = false;
 
+    bool attemptedToSetLCMS2Profile = false;
+
     // check if a color profile has been set by the user for this file
     QString profileName = getColorProfileFor(filename);
 
@@ -1454,9 +1710,12 @@ bool PQCScriptsImages::applyColorProfile(QString filename, QImage &img) {
                 targetProfile = cmsOpenProfileFromMem(bt.constData(), bt.size());
             }
 
-            if(targetProfile && applyColorSpaceLCMS2(img, filename, targetProfile))
+            attemptedToSetLCMS2Profile = true;
+
+            if(targetProfile && applyColorSpaceLCMS2(img, filename, targetProfile)) {
+                lcms2CountFailedApplications = 0;
                 return true;
-            else
+            } else
                 manualSelectionCausedError = true;
 
         }
@@ -1471,8 +1730,13 @@ bool PQCScriptsImages::applyColorProfile(QString filename, QImage &img) {
         cmsHPROFILE targetProfile = cmsOpenProfileFromMem(img.colorSpace().iccProfile().constData(),
                                                           img.colorSpace().iccProfile().size());
 
-        if(targetProfile && applyColorSpaceLCMS2(img, filename, targetProfile))
-            return !manualSelectionCausedError;
+        if(targetProfile) {
+            attemptedToSetLCMS2Profile = true;
+            if(applyColorSpaceLCMS2(img, filename, targetProfile)) {
+                lcms2CountFailedApplications = 0;
+                return !manualSelectionCausedError;
+            }
+        }
 
     }
 
@@ -1509,8 +1773,13 @@ bool PQCScriptsImages::applyColorProfile(QString filename, QImage &img) {
                     targetProfile = cmsOpenProfileFromMem(bt.constData(), bt.size());
                 }
 
-                if(targetProfile && applyColorSpaceLCMS2(img, filename, targetProfile))
-                    return !manualSelectionCausedError;
+                if(targetProfile ) {
+                    attemptedToSetLCMS2Profile = true;
+                    if(applyColorSpaceLCMS2(img, filename, targetProfile)) {
+                        lcms2CountFailedApplications = 0;
+                        return !manualSelectionCausedError;
+                    }
+                }
 
             }
 
@@ -1535,6 +1804,23 @@ bool PQCScriptsImages::applyColorProfile(QString filename, QImage &img) {
 
     }
 
+    // if a profile was attempted to be set with LCMS2 but failed (i.e., we ended up here)
+    // then we increment a counter and show a notification message.
+    // If the counter passes 5 then we disable support for color spaces.
+    if(attemptedToSetLCMS2Profile && profileName == "") {
+
+        lcms2CountFailedApplications += 1;
+
+        if(lcms2CountFailedApplications > 5) {
+            PQCSettings::get().update("imageviewColorSpaceEnable", false);
+            Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "Application of color profile failed for:") + "<br><i>" + PQCScriptsFilesPaths::get().getFilename(filename) + "</i>");
+            Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "Application of color profiles failed repeatedly. Support for color spaces will be disabled, but can be enabled again in the settings manager."));
+        } else {
+            Q_EMIT PQCNotify::get().showNotificationMessage(QCoreApplication::translate("imageprovider", "Application of color profile failed for:") + "<br><i>" + PQCScriptsFilesPaths::get().getFilename(filename) + "</i>");
+        }
+
+    }
+
     // no profile (successfully) applied, set default name
     PQCNotify::get().setColorProfileFor(filename, QColorSpace(QColorSpace::SRgb).description());
     qDebug() << "Using default color profile";
@@ -1606,11 +1892,37 @@ bool PQCScriptsImages::applyColorSpaceLCMS2(QImage &img, QString filename, cmsHP
         return false;
     } else {
 
+        // since the target format might not support alpha channels we use black instead of transparent to fill the initial image.
+        // we don't have to fill the image for cmsDoTransform but it allows for additional checking whether cmsDoTransform succeeded.
         QImage ret(img.size(), targetFormat);
-        ret.fill(Qt::transparent);
+        ret.fill(Qt::black);
+
         // Perform color space conversion
         cmsDoTransform(transform, img.constBits(), ret.bits(), img.width() * img.height());
 
+        // transform failed returning null image
+        if(ret.isNull()) {
+            qWarning() << "Failed to apply external color profile, null image returned";
+            return false;
+        }
+
+        // check if image is all black -> transform failed
+        bool allblack = true;
+        for(int x = 0; x < img.width(); ++x) {
+            for(int y = 0; y < img.height(); ++y) {
+                if(ret.pixelColor(x,y).black() < 255) {
+                    allblack = false;
+                    break;
+                }
+            }
+            if(!allblack) break;
+        }
+
+        if(allblack) {
+            qWarning() << "Failed to apply external color profile, image completely black";
+            return false;
+        }
+
         const int bufSize = 100;
         char buf[bufSize];
 
@@ -1718,9 +2030,150 @@ void PQCScriptsImages::removeThumbnailFor(QString path) {
 
     for(auto &c : cachedirs) {
         const QByteArray md5 = QCryptographicHash::hash(p,QCryptographicHash::Md5).toHex();
-        const QString thumbcachepath = PQCConfigFiles::GENERIC_CACHE_DIR() + "/thumbnails/" + c + "/" + md5 + ".png";
+        const QString thumbcachepath = PQCConfigFiles::get().THUMBNAIL_CACHE_DIR() + "/" + c + "/" + md5 + ".png";
         if(QFileInfo::exists(thumbcachepath))
             QFile::remove(thumbcachepath);
     }
 
 }
+
+double PQCScriptsImages::getPixelDensity() {
+
+#ifndef Q_OS_WIN
+
+    // 2025-01-01: Wayland issue:
+    // Fractional scaling factors are currently (Qt 6.8.1) reported as full integers by QScreen::devicePixelRatio()
+    // The same issue occurs in wayland-info (from wayland-utils 1.2.0) with the reported scale factor there
+    // However, we can try to calculate the right scaling factor from the logical and physical dimensions reported by wayland-info
+
+    // If we are on wayland...
+    if(qApp->platformName() == "wayland") {
+
+        // we cache a once calculated value for 5 minutes
+        if(QDateTime::currentMSecsSinceEpoch()-devicePixelRatioCachedWhen < 1000*60*5) {
+            return devicePixelRatioCached;
+        }
+
+        QMap<int, QList<int> > valsLogical;
+        QMap<int, QList<int> > valsPhysical;
+
+        // request all output information from wayland-info
+        QProcess proc;
+        proc.start("wayland-info", {"-i", "output"});
+        proc.waitForFinished(1000);
+        const QString out = proc.readAll();
+        const int ret = proc.exitCode();
+
+        // a return value would likely mean that wayland-info is not installed
+        // in that case we default to what was done before
+        if(ret == 0) {
+
+            // prepare variables
+            int logicalW = 0, logicalH = 0;
+            int physicalW = 0, physicalH = 0;
+            int logicalId = -1, physicalId = -1;
+
+            // go through output line by line
+            const QStringList parts = out.split("\n");
+            for(const QString &line : parts) {
+
+                // read out output ids
+                if(line.trimmed().startsWith("output:"))
+                    logicalId = line.split("output: ")[1].toInt();
+                if(line.contains("wl_output") && line.contains(", name:"))
+                    physicalId = line.split(", name: ")[1].toInt();
+
+                // read out logical dimensions
+                if(line.contains("logical_width:") && line.contains("logical_height:")) {
+                    logicalW = line.split("logical_width: ")[1].split(",")[0].toInt();
+                    logicalH = line.split("logical_height: ")[1].split("\n")[0].toInt();
+                    if(logicalId > -1)
+                        valsLogical[logicalId] = {logicalW, logicalH};
+                }
+
+                // read out physical dimensions
+                if(!line.contains("logical_width:") && !line.contains("logical_height:") && line.contains("width:") && line.contains("height:")) {
+                    physicalW = line.split("width: ")[1].split(" ")[0].toInt();
+                    physicalH = line.split("height: ")[1].split(" ")[0].toInt();
+                    if(physicalId > -1)
+                        valsPhysical[physicalId] = {physicalW, physicalH};
+                }
+
+            }
+
+            // if all screen ratios are the same, we can still make use of that
+            // if this variable is >0 a common ratio has been found
+            // a value of -1 indicates different ratios
+            double useRatio = 0;
+
+            // different amount of outputs found -> stop here
+            if(valsLogical.size() != valsPhysical.size())
+                useRatio = -1;
+
+            // same number of outputs
+            else {
+
+                // loop over all found outputs
+                QMapIterator<int, QList<int> > i(valsLogical);
+                while (i.hasNext()) {
+
+                    i.next();
+                    const int id = i.key();
+
+                    // if we have a matching physical output
+                    if(valsPhysical.contains(id)) {
+
+                        // compute the height/width ratios
+                        const double fac1 = static_cast<double>(valsPhysical.value(id).value(0))/static_cast<double>(valsLogical.value(id).value(0));
+                        const double fac2 = static_cast<double>(valsPhysical.value(id).value(1))/static_cast<double>(valsLogical.value(id).value(1));
+
+                        // if the two ratios match and make sense, return them
+                        if(fabs(fac1-fac2) < 1e-6 && fac1 > 0.25 && fac1 < 6) {
+
+                            // same ratio as before -> all good
+                            if(useRatio == 0 || fabs(useRatio-fac1) < 1e-6)
+                                useRatio = fac1;
+
+                            // different ratio -> problem
+                            else
+                                useRatio = -1;
+                        }
+
+                    } else
+                        // error -> stop
+                        useRatio = -1;
+
+                    // different ratios found
+                    if(useRatio < 0)
+                        break;
+
+                }
+
+            }
+
+            // Found single ratio across all screens
+            if(useRatio > 0) {
+
+                devicePixelRatioCached = useRatio;
+                devicePixelRatioCachedWhen = QDateTime::currentMSecsSinceEpoch();
+                return useRatio;
+
+            // if error occurred, then we effectively disable this feature
+            } else {
+
+                devicePixelRatioCached = 1;
+                devicePixelRatioCachedWhen = QDateTime::currentMSecsSinceEpoch();
+                return 1;
+
+            }
+
+        }
+
+    }
+
+#endif
+
+    // if the above didn't work, or we are on Windows
+    return qApp->devicePixelRatio();
+
+}
