@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -89,7 +89,7 @@ QString PQCScriptsMetaData::analyzeFlash(const QString val) {
     QString fYes = tr("yes");
     //: This string identifies that flash was not fired, stored in image metadata
     QString fNo = tr("no");
-    //: This string refers to the absense of a flash, stored in image metadata
+    //: This string refers to the absence of a flash, stored in image metadata
     QString fNoFlash = tr("No flash function");
     //: This string refers to a flash mode, stored in image metadata
     QString fNoStrobe = tr("strobe return light not detected");
@@ -462,6 +462,40 @@ QPointF PQCScriptsMetaData::convertGPSToPoint(QString gps) {
 
 }
 
+QString PQCScriptsMetaData::convertGPSDecimalToDegree(double lat, double lon) {
+
+    QString ret = "";
+
+    // find N/S/E/W labels
+    QString lat_dir = (lat < 0 ? " S" : (lat > 0 ? " N" : ""));
+    QString lon_dir = (lon < 0 ? " W" : (lon > 0 ? " E" : ""));
+
+    // make sure values are positive
+    lat = fabs(lat);
+    lon = fabs(lon);
+
+    // find degree
+    int lat_deg = qFloor(lat);
+    int lon_deg = qFloor(lon);
+
+    // find minute
+    double lat_min_full = (lat-lat_deg)*60;
+    double lon_min_full = (lon-lon_deg)*60;
+    int lat_min = qFloor(lat_min_full);
+    int lon_min = qFloor(lon_min_full);
+
+    // find seconds
+    double lat_sec = qRound((lat_min_full-lat_min)*60*1e3)/1e3;
+    double lon_sec = qRound((lon_min_full-lon_min)*60*1e3)/1e3;
+    
+    // assemble final string
+    ret = QString("%1° %2' %3''%4, %5° %6' %7''%8").arg(lat_deg).arg(lat_min).arg(lat_sec).arg(lat_dir)
+                                                   .arg(lon_deg).arg(lon_min).arg(lon_sec).arg(lon_dir);
+
+    return ret;
+
+}
+
 QVariantList PQCScriptsMetaData::getFaceTags(QString filename) {
 
     qDebug() << "args: filename =" << filename;
