@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -202,6 +202,17 @@ int PQCScriptsOther::getCurrentScreen(QPoint pos) {
     return 0;
 }
 
+QString PQCScriptsOther::addAlphaToColor(QString rgb, int alpha) {
+
+    qDebug() << "args: rgb =" << rgb;
+    qDebug() << "args: alpha =" << alpha;
+
+    QColor col(rgb);
+    col.setAlpha(alpha);
+    return col.name(QColor::HexArgb);
+
+}
+
 QVariantList PQCScriptsOther::convertHexToRgba(QString hex) {
 
     qDebug() << "args: hex =" << hex;
@@ -233,10 +244,17 @@ QString PQCScriptsOther::convertRgbaToHex(QVariantList rgba) {
 
     qDebug() << "args: rgba =" << rgba;
 
-    std::stringstream ss;
-    ss << "#";
-    ss << std::hex << (rgba[3].toInt() << 24 | rgba[0].toInt() << 16 | rgba[1].toInt() << 8 | rgba[2].toInt());
-    return QString::fromStdString(ss.str());
+    QColor col(qRgba(rgba[0].toInt(), rgba[1].toInt(), rgba[2].toInt(), rgba[3].toInt()));
+    return col.name(QColor::HexArgb);
+
+}
+
+QString PQCScriptsOther::convertRgbToHex(QVariantList rgb) {
+
+    qDebug() << "args: rgb =" << rgb;
+
+    QColor col(qRgb(rgb[0].toInt(), rgb[1].toInt(), rgb[2].toInt()));
+    return col.name(QColor::HexRgb);
 
 }
 
@@ -290,7 +308,7 @@ bool PQCScriptsOther::showDesktopNotification(QString summary, QString txt) {
 #ifndef Q_OS_WIN
 
     QProcess proc_notifysend;
-    proc_notifysend.start("notify-send", {"-t", "2500",
+    proc_notifysend.start("notify-send", {"-t", "5000",
                                "-a", "PhotoQt",
                                "-i", "org.photoqt.PhotoQt",
                                summary,
@@ -317,7 +335,7 @@ bool PQCScriptsOther::showDesktopNotification(QString summary, QString txt) {
                                txt,
                                "[]",
                                "{'urgency': <1>}",
-                               "2500"});
+                               "5000"});
 
     proc_gdbus.waitForFinished(1000);
     // success!
@@ -332,3 +350,16 @@ bool PQCScriptsOther::showDesktopNotification(QString summary, QString txt) {
     return false;
 
 }
+
+QStringList PQCScriptsOther::convertJSArrayToStringList(QVariant val) {
+
+    QStringList ret;
+
+    QJSValue v = val.value<QJSValue>();
+    const int length = v.property("length").toInt();
+    for(int i = 0; i < length; ++i)
+        ret << v.property(i).toString();
+
+    return ret;
+
+}
