@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2024 Lukas Spies                                  **
+ ** Copyright (C) 2011-2025 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -62,7 +62,7 @@ void PQCScriptsShareImgur::setup() {
     refresh_token = "";
 
     // Location of local file containing acces_/refresh_token
-    imgurLocalConfigFilename = PQCConfigFiles::SHAREONLINE_IMGUR_FILE();
+    imgurLocalConfigFilename = PQCConfigFiles::get().SHAREONLINE_IMGUR_FILE();
 
     // This ensures the path actually exists
     QFileInfo info(imgurLocalConfigFilename);
@@ -73,7 +73,7 @@ void PQCScriptsShareImgur::setup() {
         db = QSqlDatabase::addDatabase("QSQLITE3", "imgurhistory");
     else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
         db = QSqlDatabase::addDatabase("QSQLITE", "imgurhistory");
-    db.setDatabaseName(PQCConfigFiles::SHAREONLINE_IMGUR_HISTORY_DB());
+    db.setDatabaseName(PQCConfigFiles::get().SHAREONLINE_IMGUR_HISTORY_DB());
 
     if(!db.open()) {
         qWarning() << "ERROR opening database:" << db.lastError().text();
@@ -406,7 +406,7 @@ int PQCScriptsShareImgur::upload(QString filename) {
     connect(reply, &QNetworkReply::errorOccurred, this, &PQCScriptsShareImgur::uploadError);
     connect(this, &PQCScriptsShareImgur::abortAllRequests, reply, &QNetworkReply::abort);
 
-    // Phew, no error occured!
+    // Phew, no error occurred!
     return IMGUR_NOERROR;
 
 }
@@ -446,7 +446,7 @@ int PQCScriptsShareImgur::anonymousUpload(QString filename) {
     connect(reply, &QNetworkReply::errorOccurred, this, &PQCScriptsShareImgur::uploadError);
     connect(this, &PQCScriptsShareImgur::abortAllRequests, reply, &QNetworkReply::abort);
 
-    // Phew, no error occured!
+    // Phew, no error occurred!
     return IMGUR_NOERROR;
 
 }
@@ -508,7 +508,7 @@ void PQCScriptsShareImgur::uploadProgress(qint64 bytesSent, qint64 bytesTotal) {
 
 }
 
-// An error occured
+// An error occurred
 void PQCScriptsShareImgur::uploadError(QNetworkReply::NetworkError err) {
 
     qDebug() << "args: err =" << err;
@@ -579,7 +579,7 @@ QString PQCScriptsShareImgur::getAuthDateTime() {
 
     if(!isSetup) setup();
 
-    QFileInfo info(PQCConfigFiles::SHAREONLINE_IMGUR_FILE());
+    QFileInfo info(PQCConfigFiles::get().SHAREONLINE_IMGUR_FILE());
     if(info.exists())
         return info.lastModified().toString("yyyy-MM-dd, hh:mm:ss");
     else
